# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: FlightSql.proto
# Protobuf Python Version: 5.29.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    1,
    '',
    'FlightSql.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x46lightSql.proto\x12\x19\x61rrow.flight.protocol.sql\x1a google/protobuf/descriptor.proto\"!\n\x11\x43ommandGetSqlInfo\x12\x0c\n\x04info\x18\x01 \x03(\r\">\n\x16\x43ommandGetXdbcTypeInfo\x12\x16\n\tdata_type\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x0c\n\n_data_type\"\x14\n\x12\x43ommandGetCatalogs\"{\n\x13\x43ommandGetDbSchemas\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12%\n\x18\x64\x62_schema_filter_pattern\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\n\n\x08_catalogB\x1b\n\x19_db_schema_filter_pattern\"\xeb\x01\n\x10\x43ommandGetTables\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12%\n\x18\x64\x62_schema_filter_pattern\x18\x02 \x01(\tH\x01\x88\x01\x01\x12&\n\x19table_name_filter_pattern\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x0btable_types\x18\x04 \x03(\t\x12\x16\n\x0einclude_schema\x18\x05 \x01(\x08\x42\n\n\x08_catalogB\x1b\n\x19_db_schema_filter_patternB\x1c\n\x1a_table_name_filter_pattern\"\x16\n\x14\x43ommandGetTableTypes\"n\n\x15\x43ommandGetPrimaryKeys\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdb_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\r\n\x05table\x18\x03 \x01(\tB\n\n\x08_catalogB\x0c\n\n_db_schema\"o\n\x16\x43ommandGetExportedKeys\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdb_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\r\n\x05table\x18\x03 \x01(\tB\n\n\x08_catalogB\x0c\n\n_db_schema\"o\n\x16\x43ommandGetImportedKeys\x12\x14\n\x07\x63\x61talog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tdb_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\r\n\x05table\x18\x03 \x01(\tB\n\n\x08_catalogB\x0c\n\n_db_schema\"\xe6\x01\n\x18\x43ommandGetCrossReference\x12\x17\n\npk_catalog\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cpk_db_schema\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x08pk_table\x18\x03 \x01(\t\x12\x17\n\nfk_catalog\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x66k_db_schema\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x10\n\x08\x66k_table\x18\x06 \x01(\tB\r\n\x0b_pk_catalogB\x0f\n\r_pk_db_schemaB\r\n\x0b_fk_catalogB\x0f\n\r_fk_db_schema\"e\n$ActionCreatePreparedStatementRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\".\n\rSubstraitPlan\x12\x0c\n\x04plan\x18\x01 \x01(\x0c\x12\x0f\n\x07version\x18\x02 \x01(\t\"\x92\x01\n(ActionCreatePreparedSubstraitPlanRequest\x12\x36\n\x04plan\x18\x01 \x01(\x0b\x32(.arrow.flight.protocol.sql.SubstraitPlan\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\"z\n#ActionCreatePreparedStatementResult\x12!\n\x19prepared_statement_handle\x18\x01 \x01(\x0c\x12\x16\n\x0e\x64\x61taset_schema\x18\x02 \x01(\x0c\x12\x18\n\x10parameter_schema\x18\x03 \x01(\x0c\"H\n#ActionClosePreparedStatementRequest\x12!\n\x19prepared_statement_handle\x18\x01 \x01(\x0c\"\x1f\n\x1d\x41\x63tionBeginTransactionRequest\"C\n\x1b\x41\x63tionBeginSavepointRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x0c\x12\x0c\n\x04name\x18\x02 \x01(\t\"6\n\x1c\x41\x63tionBeginTransactionResult\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x0c\"2\n\x1a\x41\x63tionBeginSavepointResult\x12\x14\n\x0csavepoint_id\x18\x01 \x01(\x0c\"\xf9\x01\n\x1b\x41\x63tionEndTransactionRequest\x12\x16\n\x0etransaction_id\x18\x01 \x01(\x0c\x12U\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x45.arrow.flight.protocol.sql.ActionEndTransactionRequest.EndTransaction\"k\n\x0e\x45ndTransaction\x12\x1f\n\x1b\x45ND_TRANSACTION_UNSPECIFIED\x10\x00\x12\x1a\n\x16\x45ND_TRANSACTION_COMMIT\x10\x01\x12\x1c\n\x18\x45ND_TRANSACTION_ROLLBACK\x10\x02\"\xea\x01\n\x19\x41\x63tionEndSavepointRequest\x12\x14\n\x0csavepoint_id\x18\x01 \x01(\x0c\x12Q\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x41.arrow.flight.protocol.sql.ActionEndSavepointRequest.EndSavepoint\"d\n\x0c\x45ndSavepoint\x12\x1d\n\x19\x45ND_SAVEPOINT_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45ND_SAVEPOINT_RELEASE\x10\x01\x12\x1a\n\x16\x45ND_SAVEPOINT_ROLLBACK\x10\x02\"V\n\x15\x43ommandStatementQuery\x12\r\n\x05query\x18\x01 \x01(\t\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\"\x87\x01\n\x1d\x43ommandStatementSubstraitPlan\x12\x36\n\x04plan\x18\x01 \x01(\x0b\x32(.arrow.flight.protocol.sql.SubstraitPlan\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\"0\n\x14TicketStatementQuery\x12\x18\n\x10statement_handle\x18\x01 \x01(\x0c\"B\n\x1d\x43ommandPreparedStatementQuery\x12!\n\x19prepared_statement_handle\x18\x01 \x01(\x0c\"W\n\x16\x43ommandStatementUpdate\x12\r\n\x05query\x18\x01 \x01(\t\x12\x1b\n\x0etransaction_id\x18\x02 \x01(\x0cH\x00\x88\x01\x01\x42\x11\n\x0f_transaction_id\"C\n\x1e\x43ommandPreparedStatementUpdate\x12!\n\x19prepared_statement_handle\x18\x01 \x01(\x0c\"\xb6\x07\n\x16\x43ommandStatementIngest\x12j\n\x18table_definition_options\x18\x01 \x01(\x0b\x32H.arrow.flight.protocol.sql.CommandStatementIngest.TableDefinitionOptions\x12\r\n\x05table\x18\x02 \x01(\t\x12\x13\n\x06schema\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07\x63\x61talog\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x11\n\ttemporary\x18\x05 \x01(\x08\x12\x1b\n\x0etransaction_id\x18\x06 \x01(\x0cH\x02\x88\x01\x01\x12P\n\x07options\x18\xe8\x07 \x03(\x0b\x32>.arrow.flight.protocol.sql.CommandStatementIngest.OptionsEntry\x1a\x99\x04\n\x16TableDefinitionOptions\x12r\n\x0cif_not_exist\x18\x01 \x01(\x0e\x32\\.arrow.flight.protocol.sql.CommandStatementIngest.TableDefinitionOptions.TableNotExistOption\x12m\n\tif_exists\x18\x02 \x01(\x0e\x32Z.arrow.flight.protocol.sql.CommandStatementIngest.TableDefinitionOptions.TableExistsOption\"\x81\x01\n\x13TableNotExistOption\x12&\n\"TABLE_NOT_EXIST_OPTION_UNSPECIFIED\x10\x00\x12!\n\x1dTABLE_NOT_EXIST_OPTION_CREATE\x10\x01\x12\x1f\n\x1bTABLE_NOT_EXIST_OPTION_FAIL\x10\x02\"\x97\x01\n\x11TableExistsOption\x12#\n\x1fTABLE_EXISTS_OPTION_UNSPECIFIED\x10\x00\x12\x1c\n\x18TABLE_EXISTS_OPTION_FAIL\x10\x01\x12\x1e\n\x1aTABLE_EXISTS_OPTION_APPEND\x10\x02\x12\x1f\n\x1bTABLE_EXISTS_OPTION_REPLACE\x10\x03\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07_schemaB\n\n\x08_catalogB\x11\n\x0f_transaction_id\")\n\x11\x44oPutUpdateResult\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\"d\n\x1c\x44oPutPreparedStatementResult\x12&\n\x19prepared_statement_handle\x18\x01 \x01(\x0cH\x00\x88\x01\x01\x42\x1c\n\x1a_prepared_statement_handle\",\n\x18\x41\x63tionCancelQueryRequest\x12\x0c\n\x04info\x18\x01 \x01(\x0c:\x02\x18\x01\"\xfc\x01\n\x17\x41\x63tionCancelQueryResult\x12O\n\x06result\x18\x01 \x01(\x0e\x32?.arrow.flight.protocol.sql.ActionCancelQueryResult.CancelResult\"\x8b\x01\n\x0c\x43\x61ncelResult\x12\x1d\n\x19\x43\x41NCEL_RESULT_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43\x41NCEL_RESULT_CANCELLED\x10\x01\x12\x1c\n\x18\x43\x41NCEL_RESULT_CANCELLING\x10\x02\x12!\n\x1d\x43\x41NCEL_RESULT_NOT_CANCELLABLE\x10\x03:\x02\x18\x01*\x92\x19\n\x07SqlInfo\x12\x1a\n\x16\x46LIGHT_SQL_SERVER_NAME\x10\x00\x12\x1d\n\x19\x46LIGHT_SQL_SERVER_VERSION\x10\x01\x12#\n\x1f\x46LIGHT_SQL_SERVER_ARROW_VERSION\x10\x02\x12\x1f\n\x1b\x46LIGHT_SQL_SERVER_READ_ONLY\x10\x03\x12\x19\n\x15\x46LIGHT_SQL_SERVER_SQL\x10\x04\x12\x1f\n\x1b\x46LIGHT_SQL_SERVER_SUBSTRAIT\x10\x05\x12+\n\'FLIGHT_SQL_SERVER_SUBSTRAIT_MIN_VERSION\x10\x06\x12+\n\'FLIGHT_SQL_SERVER_SUBSTRAIT_MAX_VERSION\x10\x07\x12!\n\x1d\x46LIGHT_SQL_SERVER_TRANSACTION\x10\x08\x12\x1c\n\x18\x46LIGHT_SQL_SERVER_CANCEL\x10\t\x12$\n FLIGHT_SQL_SERVER_BULK_INGESTION\x10\n\x12\x33\n/FLIGHT_SQL_SERVER_INGEST_TRANSACTIONS_SUPPORTED\x10\x0b\x12\'\n#FLIGHT_SQL_SERVER_STATEMENT_TIMEOUT\x10\x64\x12)\n%FLIGHT_SQL_SERVER_TRANSACTION_TIMEOUT\x10\x65\x12\x14\n\x0fSQL_DDL_CATALOG\x10\xf4\x03\x12\x13\n\x0eSQL_DDL_SCHEMA\x10\xf5\x03\x12\x12\n\rSQL_DDL_TABLE\x10\xf6\x03\x12\x18\n\x13SQL_IDENTIFIER_CASE\x10\xf7\x03\x12\x1e\n\x19SQL_IDENTIFIER_QUOTE_CHAR\x10\xf8\x03\x12\x1f\n\x1aSQL_QUOTED_IDENTIFIER_CASE\x10\xf9\x03\x12\"\n\x1dSQL_ALL_TABLES_ARE_SELECTABLE\x10\xfa\x03\x12\x16\n\x11SQL_NULL_ORDERING\x10\xfb\x03\x12\x11\n\x0cSQL_KEYWORDS\x10\xfc\x03\x12\x1a\n\x15SQL_NUMERIC_FUNCTIONS\x10\xfd\x03\x12\x19\n\x14SQL_STRING_FUNCTIONS\x10\xfe\x03\x12\x19\n\x14SQL_SYSTEM_FUNCTIONS\x10\xff\x03\x12\x1b\n\x16SQL_DATETIME_FUNCTIONS\x10\x80\x04\x12\x1d\n\x18SQL_SEARCH_STRING_ESCAPE\x10\x81\x04\x12\x1e\n\x19SQL_EXTRA_NAME_CHARACTERS\x10\x82\x04\x12!\n\x1cSQL_SUPPORTS_COLUMN_ALIASING\x10\x83\x04\x12\x1f\n\x1aSQL_NULL_PLUS_NULL_IS_NULL\x10\x84\x04\x12\x19\n\x14SQL_SUPPORTS_CONVERT\x10\x85\x04\x12)\n$SQL_SUPPORTS_TABLE_CORRELATION_NAMES\x10\x86\x04\x12\x33\n.SQL_SUPPORTS_DIFFERENT_TABLE_CORRELATION_NAMES\x10\x87\x04\x12)\n$SQL_SUPPORTS_EXPRESSIONS_IN_ORDER_BY\x10\x88\x04\x12$\n\x1fSQL_SUPPORTS_ORDER_BY_UNRELATED\x10\x89\x04\x12\x1b\n\x16SQL_SUPPORTED_GROUP_BY\x10\x8a\x04\x12$\n\x1fSQL_SUPPORTS_LIKE_ESCAPE_CLAUSE\x10\x8b\x04\x12&\n!SQL_SUPPORTS_NON_NULLABLE_COLUMNS\x10\x8c\x04\x12\x1a\n\x15SQL_SUPPORTED_GRAMMAR\x10\x8d\x04\x12\x1f\n\x1aSQL_ANSI92_SUPPORTED_LEVEL\x10\x8e\x04\x12\x30\n+SQL_SUPPORTS_INTEGRITY_ENHANCEMENT_FACILITY\x10\x8f\x04\x12\"\n\x1dSQL_OUTER_JOINS_SUPPORT_LEVEL\x10\x90\x04\x12\x14\n\x0fSQL_SCHEMA_TERM\x10\x91\x04\x12\x17\n\x12SQL_PROCEDURE_TERM\x10\x92\x04\x12\x15\n\x10SQL_CATALOG_TERM\x10\x93\x04\x12\x19\n\x14SQL_CATALOG_AT_START\x10\x94\x04\x12\"\n\x1dSQL_SCHEMAS_SUPPORTED_ACTIONS\x10\x95\x04\x12#\n\x1eSQL_CATALOGS_SUPPORTED_ACTIONS\x10\x96\x04\x12&\n!SQL_SUPPORTED_POSITIONED_COMMANDS\x10\x97\x04\x12$\n\x1fSQL_SELECT_FOR_UPDATE_SUPPORTED\x10\x98\x04\x12$\n\x1fSQL_STORED_PROCEDURES_SUPPORTED\x10\x99\x04\x12\x1d\n\x18SQL_SUPPORTED_SUBQUERIES\x10\x9a\x04\x12(\n#SQL_CORRELATED_SUBQUERIES_SUPPORTED\x10\x9b\x04\x12\x19\n\x14SQL_SUPPORTED_UNIONS\x10\x9c\x04\x12\"\n\x1dSQL_MAX_BINARY_LITERAL_LENGTH\x10\x9d\x04\x12 \n\x1bSQL_MAX_CHAR_LITERAL_LENGTH\x10\x9e\x04\x12\x1f\n\x1aSQL_MAX_COLUMN_NAME_LENGTH\x10\x9f\x04\x12 \n\x1bSQL_MAX_COLUMNS_IN_GROUP_BY\x10\xa0\x04\x12\x1d\n\x18SQL_MAX_COLUMNS_IN_INDEX\x10\xa1\x04\x12 \n\x1bSQL_MAX_COLUMNS_IN_ORDER_BY\x10\xa2\x04\x12\x1e\n\x19SQL_MAX_COLUMNS_IN_SELECT\x10\xa3\x04\x12\x1d\n\x18SQL_MAX_COLUMNS_IN_TABLE\x10\xa4\x04\x12\x18\n\x13SQL_MAX_CONNECTIONS\x10\xa5\x04\x12\x1f\n\x1aSQL_MAX_CURSOR_NAME_LENGTH\x10\xa6\x04\x12\x19\n\x14SQL_MAX_INDEX_LENGTH\x10\xa7\x04\x12\x1e\n\x19SQL_DB_SCHEMA_NAME_LENGTH\x10\xa8\x04\x12\"\n\x1dSQL_MAX_PROCEDURE_NAME_LENGTH\x10\xa9\x04\x12 \n\x1bSQL_MAX_CATALOG_NAME_LENGTH\x10\xaa\x04\x12\x15\n\x10SQL_MAX_ROW_SIZE\x10\xab\x04\x12$\n\x1fSQL_MAX_ROW_SIZE_INCLUDES_BLOBS\x10\xac\x04\x12\x1d\n\x18SQL_MAX_STATEMENT_LENGTH\x10\xad\x04\x12\x17\n\x12SQL_MAX_STATEMENTS\x10\xae\x04\x12\x1e\n\x19SQL_MAX_TABLE_NAME_LENGTH\x10\xaf\x04\x12\x1d\n\x18SQL_MAX_TABLES_IN_SELECT\x10\xb0\x04\x12\x1c\n\x17SQL_MAX_USERNAME_LENGTH\x10\xb1\x04\x12&\n!SQL_DEFAULT_TRANSACTION_ISOLATION\x10\xb2\x04\x12\x1f\n\x1aSQL_TRANSACTIONS_SUPPORTED\x10\xb3\x04\x12\x30\n+SQL_SUPPORTED_TRANSACTIONS_ISOLATION_LEVELS\x10\xb4\x04\x12\x32\n-SQL_DATA_DEFINITION_CAUSES_TRANSACTION_COMMIT\x10\xb5\x04\x12\x31\n,SQL_DATA_DEFINITIONS_IN_TRANSACTIONS_IGNORED\x10\xb6\x04\x12#\n\x1eSQL_SUPPORTED_RESULT_SET_TYPES\x10\xb7\x04\x12;\n6SQL_SUPPORTED_CONCURRENCIES_FOR_RESULT_SET_UNSPECIFIED\x10\xb8\x04\x12<\n7SQL_SUPPORTED_CONCURRENCIES_FOR_RESULT_SET_FORWARD_ONLY\x10\xb9\x04\x12@\n;SQL_SUPPORTED_CONCURRENCIES_FOR_RESULT_SET_SCROLL_SENSITIVE\x10\xba\x04\x12\x42\n=SQL_SUPPORTED_CONCURRENCIES_FOR_RESULT_SET_SCROLL_INSENSITIVE\x10\xbb\x04\x12 \n\x1bSQL_BATCH_UPDATES_SUPPORTED\x10\xbc\x04\x12\x1d\n\x18SQL_SAVEPOINTS_SUPPORTED\x10\xbd\x04\x12#\n\x1eSQL_NAMED_PARAMETERS_SUPPORTED\x10\xbe\x04\x12\x1d\n\x18SQL_LOCATORS_UPDATE_COPY\x10\xbf\x04\x12\x35\n0SQL_STORED_FUNCTIONS_USING_CALL_SYNTAX_SUPPORTED\x10\xc0\x04*\x91\x01\n\x17SqlSupportedTransaction\x12\"\n\x1eSQL_SUPPORTED_TRANSACTION_NONE\x10\x00\x12)\n%SQL_SUPPORTED_TRANSACTION_TRANSACTION\x10\x01\x12\'\n#SQL_SUPPORTED_TRANSACTION_SAVEPOINT\x10\x02*\xb2\x01\n\x1bSqlSupportedCaseSensitivity\x12 \n\x1cSQL_CASE_SENSITIVITY_UNKNOWN\x10\x00\x12)\n%SQL_CASE_SENSITIVITY_CASE_INSENSITIVE\x10\x01\x12\"\n\x1eSQL_CASE_SENSITIVITY_UPPERCASE\x10\x02\x12\"\n\x1eSQL_CASE_SENSITIVITY_LOWERCASE\x10\x03*\x82\x01\n\x0fSqlNullOrdering\x12\x19\n\x15SQL_NULLS_SORTED_HIGH\x10\x00\x12\x18\n\x14SQL_NULLS_SORTED_LOW\x10\x01\x12\x1d\n\x19SQL_NULLS_SORTED_AT_START\x10\x02\x12\x1b\n\x17SQL_NULLS_SORTED_AT_END\x10\x03*^\n\x13SupportedSqlGrammar\x12\x17\n\x13SQL_MINIMUM_GRAMMAR\x10\x00\x12\x14\n\x10SQL_CORE_GRAMMAR\x10\x01\x12\x18\n\x14SQL_EXTENDED_GRAMMAR\x10\x02*h\n\x1eSupportedAnsi92SqlGrammarLevel\x12\x14\n\x10\x41NSI92_ENTRY_SQL\x10\x00\x12\x1b\n\x17\x41NSI92_INTERMEDIATE_SQL\x10\x01\x12\x13\n\x0f\x41NSI92_FULL_SQL\x10\x02*m\n\x19SqlOuterJoinsSupportLevel\x12\x19\n\x15SQL_JOINS_UNSUPPORTED\x10\x00\x12\x1b\n\x17SQL_LIMITED_OUTER_JOINS\x10\x01\x12\x18\n\x14SQL_FULL_OUTER_JOINS\x10\x02*Q\n\x13SqlSupportedGroupBy\x12\x1a\n\x16SQL_GROUP_BY_UNRELATED\x10\x00\x12\x1e\n\x1aSQL_GROUP_BY_BEYOND_SELECT\x10\x01*\x90\x01\n\x1aSqlSupportedElementActions\x12\"\n\x1eSQL_ELEMENT_IN_PROCEDURE_CALLS\x10\x00\x12$\n SQL_ELEMENT_IN_INDEX_DEFINITIONS\x10\x01\x12(\n$SQL_ELEMENT_IN_PRIVILEGE_DEFINITIONS\x10\x02*V\n\x1eSqlSupportedPositionedCommands\x12\x19\n\x15SQL_POSITIONED_DELETE\x10\x00\x12\x19\n\x15SQL_POSITIONED_UPDATE\x10\x01*\x97\x01\n\x16SqlSupportedSubqueries\x12!\n\x1dSQL_SUBQUERIES_IN_COMPARISONS\x10\x00\x12\x1c\n\x18SQL_SUBQUERIES_IN_EXISTS\x10\x01\x12\x19\n\x15SQL_SUBQUERIES_IN_INS\x10\x02\x12!\n\x1dSQL_SUBQUERIES_IN_QUANTIFIEDS\x10\x03*6\n\x12SqlSupportedUnions\x12\r\n\tSQL_UNION\x10\x00\x12\x11\n\rSQL_UNION_ALL\x10\x01*\xc9\x01\n\x1cSqlTransactionIsolationLevel\x12\x18\n\x14SQL_TRANSACTION_NONE\x10\x00\x12$\n SQL_TRANSACTION_READ_UNCOMMITTED\x10\x01\x12\"\n\x1eSQL_TRANSACTION_READ_COMMITTED\x10\x02\x12#\n\x1fSQL_TRANSACTION_REPEATABLE_READ\x10\x03\x12 \n\x1cSQL_TRANSACTION_SERIALIZABLE\x10\x04*\x89\x01\n\x18SqlSupportedTransactions\x12\x1f\n\x1bSQL_TRANSACTION_UNSPECIFIED\x10\x00\x12$\n SQL_DATA_DEFINITION_TRANSACTIONS\x10\x01\x12&\n\"SQL_DATA_MANIPULATION_TRANSACTIONS\x10\x02*\xbc\x01\n\x19SqlSupportedResultSetType\x12#\n\x1fSQL_RESULT_SET_TYPE_UNSPECIFIED\x10\x00\x12$\n SQL_RESULT_SET_TYPE_FORWARD_ONLY\x10\x01\x12*\n&SQL_RESULT_SET_TYPE_SCROLL_INSENSITIVE\x10\x02\x12(\n$SQL_RESULT_SET_TYPE_SCROLL_SENSITIVE\x10\x03*\xa2\x01\n SqlSupportedResultSetConcurrency\x12*\n&SQL_RESULT_SET_CONCURRENCY_UNSPECIFIED\x10\x00\x12(\n$SQL_RESULT_SET_CONCURRENCY_READ_ONLY\x10\x01\x12(\n$SQL_RESULT_SET_CONCURRENCY_UPDATABLE\x10\x02*\x99\x04\n\x12SqlSupportsConvert\x12\x16\n\x12SQL_CONVERT_BIGINT\x10\x00\x12\x16\n\x12SQL_CONVERT_BINARY\x10\x01\x12\x13\n\x0fSQL_CONVERT_BIT\x10\x02\x12\x14\n\x10SQL_CONVERT_CHAR\x10\x03\x12\x14\n\x10SQL_CONVERT_DATE\x10\x04\x12\x17\n\x13SQL_CONVERT_DECIMAL\x10\x05\x12\x15\n\x11SQL_CONVERT_FLOAT\x10\x06\x12\x17\n\x13SQL_CONVERT_INTEGER\x10\x07\x12!\n\x1dSQL_CONVERT_INTERVAL_DAY_TIME\x10\x08\x12#\n\x1fSQL_CONVERT_INTERVAL_YEAR_MONTH\x10\t\x12\x1d\n\x19SQL_CONVERT_LONGVARBINARY\x10\n\x12\x1b\n\x17SQL_CONVERT_LONGVARCHAR\x10\x0b\x12\x17\n\x13SQL_CONVERT_NUMERIC\x10\x0c\x12\x14\n\x10SQL_CONVERT_REAL\x10\r\x12\x18\n\x14SQL_CONVERT_SMALLINT\x10\x0e\x12\x14\n\x10SQL_CONVERT_TIME\x10\x0f\x12\x19\n\x15SQL_CONVERT_TIMESTAMP\x10\x10\x12\x17\n\x13SQL_CONVERT_TINYINT\x10\x11\x12\x19\n\x15SQL_CONVERT_VARBINARY\x10\x12\x12\x17\n\x13SQL_CONVERT_VARCHAR\x10\x13*\x8f\x04\n\x0cXdbcDataType\x12\x15\n\x11XDBC_UNKNOWN_TYPE\x10\x00\x12\r\n\tXDBC_CHAR\x10\x01\x12\x10\n\x0cXDBC_NUMERIC\x10\x02\x12\x10\n\x0cXDBC_DECIMAL\x10\x03\x12\x10\n\x0cXDBC_INTEGER\x10\x04\x12\x11\n\rXDBC_SMALLINT\x10\x05\x12\x0e\n\nXDBC_FLOAT\x10\x06\x12\r\n\tXDBC_REAL\x10\x07\x12\x0f\n\x0bXDBC_DOUBLE\x10\x08\x12\x11\n\rXDBC_DATETIME\x10\t\x12\x11\n\rXDBC_INTERVAL\x10\n\x12\x10\n\x0cXDBC_VARCHAR\x10\x0c\x12\r\n\tXDBC_DATE\x10[\x12\r\n\tXDBC_TIME\x10\\\x12\x12\n\x0eXDBC_TIMESTAMP\x10]\x12\x1d\n\x10XDBC_LONGVARCHAR\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x0bXDBC_BINARY\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1b\n\x0eXDBC_VARBINARY\x10\xfd\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1f\n\x12XDBC_LONGVARBINARY\x10\xfc\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x18\n\x0bXDBC_BIGINT\x10\xfb\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x19\n\x0cXDBC_TINYINT\x10\xfa\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x15\n\x08XDBC_BIT\x10\xf9\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x17\n\nXDBC_WCHAR\x10\xf8\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x1a\n\rXDBC_WVARCHAR\x10\xf7\xff\xff\xff\xff\xff\xff\xff\xff\x01*\xa3\x08\n\x13XdbcDatetimeSubcode\x12\x18\n\x14XDBC_SUBCODE_UNKNOWN\x10\x00\x12\x15\n\x11XDBC_SUBCODE_YEAR\x10\x01\x12\x15\n\x11XDBC_SUBCODE_DATE\x10\x01\x12\x15\n\x11XDBC_SUBCODE_TIME\x10\x02\x12\x16\n\x12XDBC_SUBCODE_MONTH\x10\x02\x12\x1a\n\x16XDBC_SUBCODE_TIMESTAMP\x10\x03\x12\x14\n\x10XDBC_SUBCODE_DAY\x10\x03\x12#\n\x1fXDBC_SUBCODE_TIME_WITH_TIMEZONE\x10\x04\x12\x15\n\x11XDBC_SUBCODE_HOUR\x10\x04\x12(\n$XDBC_SUBCODE_TIMESTAMP_WITH_TIMEZONE\x10\x05\x12\x17\n\x13XDBC_SUBCODE_MINUTE\x10\x05\x12\x17\n\x13XDBC_SUBCODE_SECOND\x10\x06\x12\x1e\n\x1aXDBC_SUBCODE_YEAR_TO_MONTH\x10\x07\x12\x1c\n\x18XDBC_SUBCODE_DAY_TO_HOUR\x10\x08\x12\x1e\n\x1aXDBC_SUBCODE_DAY_TO_MINUTE\x10\t\x12\x1e\n\x1aXDBC_SUBCODE_DAY_TO_SECOND\x10\n\x12\x1f\n\x1bXDBC_SUBCODE_HOUR_TO_MINUTE\x10\x0b\x12\x1f\n\x1bXDBC_SUBCODE_HOUR_TO_SECOND\x10\x0c\x12!\n\x1dXDBC_SUBCODE_MINUTE_TO_SECOND\x10\r\x12\x1e\n\x1aXDBC_SUBCODE_INTERVAL_YEAR\x10\x65\x12\x1f\n\x1bXDBC_SUBCODE_INTERVAL_MONTH\x10\x66\x12\x1d\n\x19XDBC_SUBCODE_INTERVAL_DAY\x10g\x12\x1e\n\x1aXDBC_SUBCODE_INTERVAL_HOUR\x10h\x12 \n\x1cXDBC_SUBCODE_INTERVAL_MINUTE\x10i\x12 \n\x1cXDBC_SUBCODE_INTERVAL_SECOND\x10j\x12\'\n#XDBC_SUBCODE_INTERVAL_YEAR_TO_MONTH\x10k\x12%\n!XDBC_SUBCODE_INTERVAL_DAY_TO_HOUR\x10l\x12\'\n#XDBC_SUBCODE_INTERVAL_DAY_TO_MINUTE\x10m\x12\'\n#XDBC_SUBCODE_INTERVAL_DAY_TO_SECOND\x10n\x12(\n$XDBC_SUBCODE_INTERVAL_HOUR_TO_MINUTE\x10o\x12(\n$XDBC_SUBCODE_INTERVAL_HOUR_TO_SECOND\x10p\x12*\n&XDBC_SUBCODE_INTERVAL_MINUTE_TO_SECOND\x10q\x1a\x02\x10\x01*W\n\x08Nullable\x12\x18\n\x14NULLABILITY_NO_NULLS\x10\x00\x12\x18\n\x14NULLABILITY_NULLABLE\x10\x01\x12\x17\n\x13NULLABILITY_UNKNOWN\x10\x02*a\n\nSearchable\x12\x13\n\x0fSEARCHABLE_NONE\x10\x00\x12\x13\n\x0fSEARCHABLE_CHAR\x10\x01\x12\x14\n\x10SEARCHABLE_BASIC\x10\x02\x12\x13\n\x0fSEARCHABLE_FULL\x10\x03*\\\n\x11UpdateDeleteRules\x12\x0b\n\x07\x43\x41SCADE\x10\x00\x12\x0c\n\x08RESTRICT\x10\x01\x12\x0c\n\x08SET_NULL\x10\x02\x12\r\n\tNO_ACTION\x10\x03\x12\x0f\n\x0bSET_DEFAULT\x10\x04:6\n\x0c\x65xperimental\x12\x1f.google.protobuf.MessageOptions\x18\xe8\x07 \x01(\x08\x42V\n org.apache.arrow.flight.sql.implZ2github.com/apache/arrow-go/arrow/flight/gen/flightb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'FlightSql_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n org.apache.arrow.flight.sql.implZ2github.com/apache/arrow-go/arrow/flight/gen/flight'
  _globals['_XDBCDATETIMESUBCODE']._loaded_options = None
  _globals['_XDBCDATETIMESUBCODE']._serialized_options = b'\020\001'
  _globals['_COMMANDSTATEMENTINGEST_OPTIONSENTRY']._loaded_options = None
  _globals['_COMMANDSTATEMENTINGEST_OPTIONSENTRY']._serialized_options = b'8\001'
  _globals['_ACTIONCANCELQUERYREQUEST']._loaded_options = None
  _globals['_ACTIONCANCELQUERYREQUEST']._serialized_options = b'\030\001'
  _globals['_ACTIONCANCELQUERYRESULT']._loaded_options = None
  _globals['_ACTIONCANCELQUERYRESULT']._serialized_options = b'\030\001'
  _globals['_SQLINFO']._serialized_start=4258
  _globals['_SQLINFO']._serialized_end=7476
  _globals['_SQLSUPPORTEDTRANSACTION']._serialized_start=7479
  _globals['_SQLSUPPORTEDTRANSACTION']._serialized_end=7624
  _globals['_SQLSUPPORTEDCASESENSITIVITY']._serialized_start=7627
  _globals['_SQLSUPPORTEDCASESENSITIVITY']._serialized_end=7805
  _globals['_SQLNULLORDERING']._serialized_start=7808
  _globals['_SQLNULLORDERING']._serialized_end=7938
  _globals['_SUPPORTEDSQLGRAMMAR']._serialized_start=7940
  _globals['_SUPPORTEDSQLGRAMMAR']._serialized_end=8034
  _globals['_SUPPORTEDANSI92SQLGRAMMARLEVEL']._serialized_start=8036
  _globals['_SUPPORTEDANSI92SQLGRAMMARLEVEL']._serialized_end=8140
  _globals['_SQLOUTERJOINSSUPPORTLEVEL']._serialized_start=8142
  _globals['_SQLOUTERJOINSSUPPORTLEVEL']._serialized_end=8251
  _globals['_SQLSUPPORTEDGROUPBY']._serialized_start=8253
  _globals['_SQLSUPPORTEDGROUPBY']._serialized_end=8334
  _globals['_SQLSUPPORTEDELEMENTACTIONS']._serialized_start=8337
  _globals['_SQLSUPPORTEDELEMENTACTIONS']._serialized_end=8481
  _globals['_SQLSUPPORTEDPOSITIONEDCOMMANDS']._serialized_start=8483
  _globals['_SQLSUPPORTEDPOSITIONEDCOMMANDS']._serialized_end=8569
  _globals['_SQLSUPPORTEDSUBQUERIES']._serialized_start=8572
  _globals['_SQLSUPPORTEDSUBQUERIES']._serialized_end=8723
  _globals['_SQLSUPPORTEDUNIONS']._serialized_start=8725
  _globals['_SQLSUPPORTEDUNIONS']._serialized_end=8779
  _globals['_SQLTRANSACTIONISOLATIONLEVEL']._serialized_start=8782
  _globals['_SQLTRANSACTIONISOLATIONLEVEL']._serialized_end=8983
  _globals['_SQLSUPPORTEDTRANSACTIONS']._serialized_start=8986
  _globals['_SQLSUPPORTEDTRANSACTIONS']._serialized_end=9123
  _globals['_SQLSUPPORTEDRESULTSETTYPE']._serialized_start=9126
  _globals['_SQLSUPPORTEDRESULTSETTYPE']._serialized_end=9314
  _globals['_SQLSUPPORTEDRESULTSETCONCURRENCY']._serialized_start=9317
  _globals['_SQLSUPPORTEDRESULTSETCONCURRENCY']._serialized_end=9479
  _globals['_SQLSUPPORTSCONVERT']._serialized_start=9482
  _globals['_SQLSUPPORTSCONVERT']._serialized_end=10019
  _globals['_XDBCDATATYPE']._serialized_start=10022
  _globals['_XDBCDATATYPE']._serialized_end=10549
  _globals['_XDBCDATETIMESUBCODE']._serialized_start=10552
  _globals['_XDBCDATETIMESUBCODE']._serialized_end=11611
  _globals['_NULLABLE']._serialized_start=11613
  _globals['_NULLABLE']._serialized_end=11700
  _globals['_SEARCHABLE']._serialized_start=11702
  _globals['_SEARCHABLE']._serialized_end=11799
  _globals['_UPDATEDELETERULES']._serialized_start=11801
  _globals['_UPDATEDELETERULES']._serialized_end=11893
  _globals['_COMMANDGETSQLINFO']._serialized_start=80
  _globals['_COMMANDGETSQLINFO']._serialized_end=113
  _globals['_COMMANDGETXDBCTYPEINFO']._serialized_start=115
  _globals['_COMMANDGETXDBCTYPEINFO']._serialized_end=177
  _globals['_COMMANDGETCATALOGS']._serialized_start=179
  _globals['_COMMANDGETCATALOGS']._serialized_end=199
  _globals['_COMMANDGETDBSCHEMAS']._serialized_start=201
  _globals['_COMMANDGETDBSCHEMAS']._serialized_end=324
  _globals['_COMMANDGETTABLES']._serialized_start=327
  _globals['_COMMANDGETTABLES']._serialized_end=562
  _globals['_COMMANDGETTABLETYPES']._serialized_start=564
  _globals['_COMMANDGETTABLETYPES']._serialized_end=586
  _globals['_COMMANDGETPRIMARYKEYS']._serialized_start=588
  _globals['_COMMANDGETPRIMARYKEYS']._serialized_end=698
  _globals['_COMMANDGETEXPORTEDKEYS']._serialized_start=700
  _globals['_COMMANDGETEXPORTEDKEYS']._serialized_end=811
  _globals['_COMMANDGETIMPORTEDKEYS']._serialized_start=813
  _globals['_COMMANDGETIMPORTEDKEYS']._serialized_end=924
  _globals['_COMMANDGETCROSSREFERENCE']._serialized_start=927
  _globals['_COMMANDGETCROSSREFERENCE']._serialized_end=1157
  _globals['_ACTIONCREATEPREPAREDSTATEMENTREQUEST']._serialized_start=1159
  _globals['_ACTIONCREATEPREPAREDSTATEMENTREQUEST']._serialized_end=1260
  _globals['_SUBSTRAITPLAN']._serialized_start=1262
  _globals['_SUBSTRAITPLAN']._serialized_end=1308
  _globals['_ACTIONCREATEPREPAREDSUBSTRAITPLANREQUEST']._serialized_start=1311
  _globals['_ACTIONCREATEPREPAREDSUBSTRAITPLANREQUEST']._serialized_end=1457
  _globals['_ACTIONCREATEPREPAREDSTATEMENTRESULT']._serialized_start=1459
  _globals['_ACTIONCREATEPREPAREDSTATEMENTRESULT']._serialized_end=1581
  _globals['_ACTIONCLOSEPREPAREDSTATEMENTREQUEST']._serialized_start=1583
  _globals['_ACTIONCLOSEPREPAREDSTATEMENTREQUEST']._serialized_end=1655
  _globals['_ACTIONBEGINTRANSACTIONREQUEST']._serialized_start=1657
  _globals['_ACTIONBEGINTRANSACTIONREQUEST']._serialized_end=1688
  _globals['_ACTIONBEGINSAVEPOINTREQUEST']._serialized_start=1690
  _globals['_ACTIONBEGINSAVEPOINTREQUEST']._serialized_end=1757
  _globals['_ACTIONBEGINTRANSACTIONRESULT']._serialized_start=1759
  _globals['_ACTIONBEGINTRANSACTIONRESULT']._serialized_end=1813
  _globals['_ACTIONBEGINSAVEPOINTRESULT']._serialized_start=1815
  _globals['_ACTIONBEGINSAVEPOINTRESULT']._serialized_end=1865
  _globals['_ACTIONENDTRANSACTIONREQUEST']._serialized_start=1868
  _globals['_ACTIONENDTRANSACTIONREQUEST']._serialized_end=2117
  _globals['_ACTIONENDTRANSACTIONREQUEST_ENDTRANSACTION']._serialized_start=2010
  _globals['_ACTIONENDTRANSACTIONREQUEST_ENDTRANSACTION']._serialized_end=2117
  _globals['_ACTIONENDSAVEPOINTREQUEST']._serialized_start=2120
  _globals['_ACTIONENDSAVEPOINTREQUEST']._serialized_end=2354
  _globals['_ACTIONENDSAVEPOINTREQUEST_ENDSAVEPOINT']._serialized_start=2254
  _globals['_ACTIONENDSAVEPOINTREQUEST_ENDSAVEPOINT']._serialized_end=2354
  _globals['_COMMANDSTATEMENTQUERY']._serialized_start=2356
  _globals['_COMMANDSTATEMENTQUERY']._serialized_end=2442
  _globals['_COMMANDSTATEMENTSUBSTRAITPLAN']._serialized_start=2445
  _globals['_COMMANDSTATEMENTSUBSTRAITPLAN']._serialized_end=2580
  _globals['_TICKETSTATEMENTQUERY']._serialized_start=2582
  _globals['_TICKETSTATEMENTQUERY']._serialized_end=2630
  _globals['_COMMANDPREPAREDSTATEMENTQUERY']._serialized_start=2632
  _globals['_COMMANDPREPAREDSTATEMENTQUERY']._serialized_end=2698
  _globals['_COMMANDSTATEMENTUPDATE']._serialized_start=2700
  _globals['_COMMANDSTATEMENTUPDATE']._serialized_end=2787
  _globals['_COMMANDPREPAREDSTATEMENTUPDATE']._serialized_start=2789
  _globals['_COMMANDPREPAREDSTATEMENTUPDATE']._serialized_end=2856
  _globals['_COMMANDSTATEMENTINGEST']._serialized_start=2859
  _globals['_COMMANDSTATEMENTINGEST']._serialized_end=3809
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS']._serialized_start=3182
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS']._serialized_end=3719
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS_TABLENOTEXISTOPTION']._serialized_start=3436
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS_TABLENOTEXISTOPTION']._serialized_end=3565
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS_TABLEEXISTSOPTION']._serialized_start=3568
  _globals['_COMMANDSTATEMENTINGEST_TABLEDEFINITIONOPTIONS_TABLEEXISTSOPTION']._serialized_end=3719
  _globals['_COMMANDSTATEMENTINGEST_OPTIONSENTRY']._serialized_start=3721
  _globals['_COMMANDSTATEMENTINGEST_OPTIONSENTRY']._serialized_end=3767
  _globals['_DOPUTUPDATERESULT']._serialized_start=3811
  _globals['_DOPUTUPDATERESULT']._serialized_end=3852
  _globals['_DOPUTPREPAREDSTATEMENTRESULT']._serialized_start=3854
  _globals['_DOPUTPREPAREDSTATEMENTRESULT']._serialized_end=3954
  _globals['_ACTIONCANCELQUERYREQUEST']._serialized_start=3956
  _globals['_ACTIONCANCELQUERYREQUEST']._serialized_end=4000
  _globals['_ACTIONCANCELQUERYRESULT']._serialized_start=4003
  _globals['_ACTIONCANCELQUERYRESULT']._serialized_end=4255
  _globals['_ACTIONCANCELQUERYRESULT_CANCELRESULT']._serialized_start=4112
  _globals['_ACTIONCANCELQUERYRESULT_CANCELRESULT']._serialized_end=4251
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/gpu/gpu_counter_event.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/gpu/gpu_counter_event.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.common import gpu_counter_descriptor_pb2 as protos_dot_perfetto_dot_common_dot_gpu__counter__descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1protos/perfetto/trace/gpu/gpu_counter_event.proto\x12\x0fperfetto.protos\x1a\x33protos/perfetto/common/gpu_counter_descriptor.proto\"\xfb\x01\n\x0fGpuCounterEvent\x12\x41\n\x12\x63ounter_descriptor\x18\x01 \x01(\x0b\x32%.perfetto.protos.GpuCounterDescriptor\x12=\n\x08\x63ounters\x18\x02 \x03(\x0b\x32+.perfetto.protos.GpuCounterEvent.GpuCounter\x12\x0e\n\x06gpu_id\x18\x03 \x01(\x05\x1aV\n\nGpuCounter\x12\x12\n\ncounter_id\x18\x01 \x01(\r\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x42\x07\n\x05value')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.gpu.gpu_counter_event_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GPUCOUNTEREVENT']._serialized_start=124
  _globals['_GPUCOUNTEREVENT']._serialized_end=375
  _globals['_GPUCOUNTEREVENT_GPUCOUNTER']._serialized_start=289
  _globals['_GPUCOUNTEREVENT_GPUCOUNTER']._serialized_end=375
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/power/battery_counters.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/power/battery_counters.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2protos/perfetto/trace/power/battery_counters.proto\x12\x0fperfetto.protos\"\xb1\x01\n\x0f\x42\x61tteryCounters\x12\x1a\n\x12\x63harge_counter_uah\x18\x01 \x01(\x03\x12\x18\n\x10\x63\x61pacity_percent\x18\x02 \x01(\x02\x12\x12\n\ncurrent_ua\x18\x03 \x01(\x03\x12\x16\n\x0e\x63urrent_avg_ua\x18\x04 \x01(\x03\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x1a\n\x12\x65nergy_counter_uwh\x18\x06 \x01(\x03\x12\x12\n\nvoltage_uv\x18\x07 \x01(\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.power.battery_counters_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BATTERYCOUNTERS']._serialized_start=72
  _globals['_BATTERYCOUNTERS']._serialized_end=249
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/config/profiling/perf_event_config.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/config/profiling/perf_event_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.common import perf_events_pb2 as protos_dot_perfetto_dot_common_dot_perf__events__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8protos/perfetto/config/profiling/perf_event_config.proto\x12\x0fperfetto.protos\x1a(protos/perfetto/common/perf_events.proto\"\xd7\x07\n\x0fPerfEventConfig\x12\x36\n\x08timebase\x18\x0f \x01(\x0b\x32$.perfetto.protos.PerfEvents.Timebase\x12N\n\x12\x63\x61llstack_sampling\x18\x10 \x01(\x0b\x32\x32.perfetto.protos.PerfEventConfig.CallstackSampling\x12\"\n\x1aring_buffer_read_period_ms\x18\x08 \x01(\r\x12\x19\n\x11ring_buffer_pages\x18\x03 \x01(\r\x12!\n\x19max_enqueued_footprint_kb\x18\x11 \x01(\x04\x12\x1c\n\x14max_daemon_memory_kb\x18\r \x01(\r\x12$\n\x1cremote_descriptor_timeout_ms\x18\t \x01(\r\x12$\n\x1cunwind_state_clear_period_ms\x18\n \x01(\r\x12\x1b\n\x13target_installed_by\x18\x12 \x03(\t\x12\x10\n\x08\x61ll_cpus\x18\x01 \x01(\x08\x12\x1a\n\x12sampling_frequency\x18\x02 \x01(\r\x12\x15\n\rkernel_frames\x18\x0c \x01(\x08\x12\x12\n\ntarget_pid\x18\x04 \x03(\x05\x12\x16\n\x0etarget_cmdline\x18\x05 \x03(\t\x12\x13\n\x0b\x65xclude_pid\x18\x06 \x03(\x05\x12\x17\n\x0f\x65xclude_cmdline\x18\x07 \x03(\t\x12 \n\x18\x61\x64\x64itional_cmdline_count\x18\x0b \x01(\r\x1a\xa3\x01\n\x11\x43\x61llstackSampling\x12\x35\n\x05scope\x18\x01 \x01(\x0b\x32&.perfetto.protos.PerfEventConfig.Scope\x12\x15\n\rkernel_frames\x18\x02 \x01(\x08\x12@\n\x0buser_frames\x18\x03 \x01(\x0e\x32+.perfetto.protos.PerfEventConfig.UnwindMode\x1a\xa0\x01\n\x05Scope\x12\x12\n\ntarget_pid\x18\x01 \x03(\x05\x12\x16\n\x0etarget_cmdline\x18\x02 \x03(\t\x12\x13\n\x0b\x65xclude_pid\x18\x03 \x03(\x05\x12\x17\n\x0f\x65xclude_cmdline\x18\x04 \x03(\t\x12 \n\x18\x61\x64\x64itional_cmdline_count\x18\x05 \x01(\r\x12\x1b\n\x13process_shard_count\x18\x06 \x01(\r\"C\n\nUnwindMode\x12\x12\n\x0eUNWIND_UNKNOWN\x10\x00\x12\x0f\n\x0bUNWIND_SKIP\x10\x01\x12\x10\n\x0cUNWIND_DWARF\x10\x02J\x04\x08\x0e\x10\x0f')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.config.profiling.perf_event_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PERFEVENTCONFIG']._serialized_start=120
  _globals['_PERFEVENTCONFIG']._serialized_end=1103
  _globals['_PERFEVENTCONFIG_CALLSTACKSAMPLING']._serialized_start=702
  _globals['_PERFEVENTCONFIG_CALLSTACKSAMPLING']._serialized_end=865
  _globals['_PERFEVENTCONFIG_SCOPE']._serialized_start=868
  _globals['_PERFEVENTCONFIG_SCOPE']._serialized_end=1028
  _globals['_PERFEVENTCONFIG_UNWINDMODE']._serialized_start=1030
  _globals['_PERFEVENTCONFIG_UNWINDMODE']._serialized_end=1097
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/android/shell_transition.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/android/shell_transition.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4protos/perfetto/trace/android/shell_transition.proto\x12\x0fperfetto.protos\"\x99\x04\n\x0fShellTransition\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x16\n\x0e\x63reate_time_ns\x18\x02 \x01(\x03\x12\x14\n\x0csend_time_ns\x18\x03 \x01(\x03\x12\x18\n\x10\x64ispatch_time_ns\x18\x04 \x01(\x03\x12\x15\n\rmerge_time_ns\x18\x05 \x01(\x03\x12\x1d\n\x15merge_request_time_ns\x18\x06 \x01(\x03\x12\x1b\n\x13shell_abort_time_ns\x18\x07 \x01(\x03\x12\x18\n\x10wm_abort_time_ns\x18\x08 \x01(\x03\x12\x16\n\x0e\x66inish_time_ns\x18\t \x01(\x03\x12\x1c\n\x14start_transaction_id\x18\n \x01(\x04\x12\x1d\n\x15\x66inish_transaction_id\x18\x0b \x01(\x04\x12\x0f\n\x07handler\x18\x0c \x01(\x05\x12\x0c\n\x04type\x18\r \x01(\x05\x12\x38\n\x07targets\x18\x0e \x03(\x0b\x32\'.perfetto.protos.ShellTransition.Target\x12\x14\n\x0cmerge_target\x18\x0f \x01(\x05\x12\r\n\x05\x66lags\x18\x10 \x01(\x05\x12&\n\x1estarting_window_remove_time_ns\x18\x11 \x01(\x03\x1aJ\n\x06Target\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x10\n\x08layer_id\x18\x02 \x01(\x05\x12\x11\n\twindow_id\x18\x03 \x01(\x05\x12\r\n\x05\x66lags\x18\x04 \x01(\x05\"M\n\x14ShellHandlerMappings\x12\x35\n\x07mapping\x18\x01 \x03(\x0b\x32$.perfetto.protos.ShellHandlerMapping\"/\n\x13ShellHandlerMapping\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.android.shell_transition_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SHELLTRANSITION']._serialized_start=74
  _globals['_SHELLTRANSITION']._serialized_end=611
  _globals['_SHELLTRANSITION_TARGET']._serialized_start=537
  _globals['_SHELLTRANSITION_TARGET']._serialized_end=611
  _globals['_SHELLHANDLERMAPPINGS']._serialized_start=613
  _globals['_SHELLHANDLERMAPPINGS']._serialized_end=690
  _globals['_SHELLHANDLERMAPPING']._serialized_start=692
  _globals['_SHELLHANDLERMAPPING']._serialized_end=739
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/memory_graph.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/memory_graph.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(protos/perfetto/trace/memory_graph.proto\x12\x0fperfetto.protos\"\xf0\x07\n\x15MemoryTrackerSnapshot\x12\x16\n\x0eglobal_dump_id\x18\x01 \x01(\x04\x12M\n\x0flevel_of_detail\x18\x02 \x01(\x0e\x32\x34.perfetto.protos.MemoryTrackerSnapshot.LevelOfDetail\x12T\n\x14process_memory_dumps\x18\x03 \x03(\x0b\x32\x36.perfetto.protos.MemoryTrackerSnapshot.ProcessSnapshot\x1a\xce\x05\n\x0fProcessSnapshot\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12Z\n\x0f\x61llocator_dumps\x18\x02 \x03(\x0b\x32\x41.perfetto.protos.MemoryTrackerSnapshot.ProcessSnapshot.MemoryNode\x12W\n\x0cmemory_edges\x18\x03 \x03(\x0b\x32\x41.perfetto.protos.MemoryTrackerSnapshot.ProcessSnapshot.MemoryEdge\x1a\x9b\x03\n\nMemoryNode\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x15\n\rabsolute_name\x18\x02 \x01(\t\x12\x0c\n\x04weak\x18\x03 \x01(\x08\x12\x12\n\nsize_bytes\x18\x04 \x01(\x04\x12\x62\n\x07\x65ntries\x18\x05 \x03(\x0b\x32Q.perfetto.protos.MemoryTrackerSnapshot.ProcessSnapshot.MemoryNode.MemoryNodeEntry\x1a\xe3\x01\n\x0fMemoryNodeEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x66\n\x05units\x18\x02 \x01(\x0e\x32W.perfetto.protos.MemoryTrackerSnapshot.ProcessSnapshot.MemoryNode.MemoryNodeEntry.Units\x12\x14\n\x0cvalue_uint64\x18\x03 \x01(\x04\x12\x14\n\x0cvalue_string\x18\x04 \x01(\t\".\n\x05Units\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\t\n\x05\x43OUNT\x10\x02\x1a[\n\nMemoryEdge\x12\x11\n\tsource_id\x18\x01 \x01(\x04\x12\x11\n\ttarget_id\x18\x02 \x01(\x04\x12\x12\n\nimportance\x18\x03 \x01(\r\x12\x13\n\x0boverridable\x18\x04 \x01(\x08\"I\n\rLevelOfDetail\x12\x0f\n\x0b\x44\x45TAIL_FULL\x10\x00\x12\x10\n\x0c\x44\x45TAIL_LIGHT\x10\x01\x12\x15\n\x11\x44\x45TAIL_BACKGROUND\x10\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.memory_graph_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MEMORYTRACKERSNAPSHOT']._serialized_start=62
  _globals['_MEMORYTRACKERSNAPSHOT']._serialized_end=1070
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT']._serialized_start=277
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT']._serialized_end=995
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT_MEMORYNODE']._serialized_start=491
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT_MEMORYNODE']._serialized_end=902
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT_MEMORYNODE_MEMORYNODEENTRY']._serialized_start=675
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT_MEMORYNODE_MEMORYNODEENTRY']._serialized_end=902
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT_MEMORYNODE_MEMORYNODEENTRY_UNITS']._serialized_start=856
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT_MEMORYNODE_MEMORYNODEENTRY_UNITS']._serialized_end=902
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT_MEMORYEDGE']._serialized_start=904
  _globals['_MEMORYTRACKERSNAPSHOT_PROCESSSNAPSHOT_MEMORYEDGE']._serialized_end=995
  _globals['_MEMORYTRACKERSNAPSHOT_LEVELOFDETAIL']._serialized_start=997
  _globals['_MEMORYTRACKERSNAPSHOT_LEVELOFDETAIL']._serialized_end=1070
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/sched.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/sched.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(protos/perfetto/trace/ftrace/sched.proto\x12\x0fperfetto.protos\"\x9c\x01\n\x16SchedSwitchFtraceEvent\x12\x11\n\tprev_comm\x18\x01 \x01(\t\x12\x10\n\x08prev_pid\x18\x02 \x01(\x05\x12\x11\n\tprev_prio\x18\x03 \x01(\x05\x12\x12\n\nprev_state\x18\x04 \x01(\x03\x12\x11\n\tnext_comm\x18\x05 \x01(\t\x12\x10\n\x08next_pid\x18\x06 \x01(\x05\x12\x11\n\tnext_prio\x18\x07 \x01(\x05\"f\n\x16SchedWakeupFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04prio\x18\x03 \x01(\x05\x12\x0f\n\x07success\x18\x04 \x01(\x05\x12\x12\n\ntarget_cpu\x18\x05 \x01(\x05\"M\n\x1dSchedBlockedReasonFtraceEvent\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x0e\n\x06\x63\x61ller\x18\x02 \x01(\x04\x12\x0f\n\x07io_wait\x18\x03 \x01(\r\"Q\n\x1aSchedCpuHotplugFtraceEvent\x12\x14\n\x0c\x61\x66\x66\x65\x63ted_cpu\x18\x01 \x01(\x05\x12\r\n\x05\x65rror\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\x05\"f\n\x16SchedWakingFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04prio\x18\x03 \x01(\x05\x12\x0f\n\x07success\x18\x04 \x01(\x05\x12\x12\n\ntarget_cpu\x18\x05 \x01(\x05\"i\n\x19SchedWakeupNewFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04prio\x18\x03 \x01(\x05\x12\x0f\n\x07success\x18\x04 \x01(\x05\x12\x12\n\ntarget_cpu\x18\x05 \x01(\x05\"M\n\x1bSchedProcessExecFtraceEvent\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0f\n\x07old_pid\x18\x03 \x01(\x05\"T\n\x1bSchedProcessExitFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04tgid\x18\x03 \x01(\x05\x12\x0c\n\x04prio\x18\x04 \x01(\x05\"m\n\x1bSchedProcessForkFtraceEvent\x12\x13\n\x0bparent_comm\x18\x01 \x01(\t\x12\x12\n\nparent_pid\x18\x02 \x01(\x05\x12\x12\n\nchild_comm\x18\x03 \x01(\t\x12\x11\n\tchild_pid\x18\x04 \x01(\x05\"F\n\x1bSchedProcessFreeFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04prio\x18\x03 \x01(\x05\"8\n\x1bSchedProcessHangFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\"F\n\x1bSchedProcessWaitFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04prio\x18\x03 \x01(\x05\"X\n\x19SchedPiSetprioFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0f\n\x07newprio\x18\x02 \x01(\x05\x12\x0f\n\x07oldprio\x18\x03 \x01(\x05\x12\x0b\n\x03pid\x18\x04 \x01(\x05\"\xc8\x02\n\x1aSchedCpuUtilCfsFtraceEvent\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x05\x12\x10\n\x08\x63\x61pacity\x18\x02 \x01(\x04\x12\x15\n\rcapacity_orig\x18\x03 \x01(\x04\x12\x0b\n\x03\x63pu\x18\x04 \x01(\r\x12\x16\n\x0e\x63pu_importance\x18\x05 \x01(\x04\x12\x10\n\x08\x63pu_util\x18\x06 \x01(\x04\x12\x10\n\x08\x65xit_lat\x18\x07 \x01(\r\x12\x16\n\x0egroup_capacity\x18\x08 \x01(\x04\x12\x18\n\x10grp_overutilized\x18\t \x01(\r\x12\x10\n\x08idle_cpu\x18\n \x01(\r\x12\x12\n\nnr_running\x18\x0b \x01(\r\x12\x11\n\tspare_cap\x18\x0c \x01(\x03\x12\x11\n\ttask_fits\x18\r \x01(\r\x12\x17\n\x0fwake_group_util\x18\x0e \x01(\x04\x12\x11\n\twake_util\x18\x0f \x01(\x04\"\x89\x01\n\x1bSchedMigrateTaskFtraceEvent\x12\x0c\n\x04\x63omm\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04prio\x18\x03 \x01(\x05\x12\x10\n\x08orig_cpu\x18\x04 \x01(\x05\x12\x10\n\x08\x64\x65st_cpu\x18\x05 \x01(\x05\x12\x0f\n\x07running\x18\x06 \x01(\x05\x12\x0c\n\x04load\x18\x07 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.sched_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SCHEDSWITCHFTRACEEVENT']._serialized_start=62
  _globals['_SCHEDSWITCHFTRACEEVENT']._serialized_end=218
  _globals['_SCHEDWAKEUPFTRACEEVENT']._serialized_start=220
  _globals['_SCHEDWAKEUPFTRACEEVENT']._serialized_end=322
  _globals['_SCHEDBLOCKEDREASONFTRACEEVENT']._serialized_start=324
  _globals['_SCHEDBLOCKEDREASONFTRACEEVENT']._serialized_end=401
  _globals['_SCHEDCPUHOTPLUGFTRACEEVENT']._serialized_start=403
  _globals['_SCHEDCPUHOTPLUGFTRACEEVENT']._serialized_end=484
  _globals['_SCHEDWAKINGFTRACEEVENT']._serialized_start=486
  _globals['_SCHEDWAKINGFTRACEEVENT']._serialized_end=588
  _globals['_SCHEDWAKEUPNEWFTRACEEVENT']._serialized_start=590
  _globals['_SCHEDWAKEUPNEWFTRACEEVENT']._serialized_end=695
  _globals['_SCHEDPROCESSEXECFTRACEEVENT']._serialized_start=697
  _globals['_SCHEDPROCESSEXECFTRACEEVENT']._serialized_end=774
  _globals['_SCHEDPROCESSEXITFTRACEEVENT']._serialized_start=776
  _globals['_SCHEDPROCESSEXITFTRACEEVENT']._serialized_end=860
  _globals['_SCHEDPROCESSFORKFTRACEEVENT']._serialized_start=862
  _globals['_SCHEDPROCESSFORKFTRACEEVENT']._serialized_end=971
  _globals['_SCHEDPROCESSFREEFTRACEEVENT']._serialized_start=973
  _globals['_SCHEDPROCESSFREEFTRACEEVENT']._serialized_end=1043
  _globals['_SCHEDPROCESSHANGFTRACEEVENT']._serialized_start=1045
  _globals['_SCHEDPROCESSHANGFTRACEEVENT']._serialized_end=1101
  _globals['_SCHEDPROCESSWAITFTRACEEVENT']._serialized_start=1103
  _globals['_SCHEDPROCESSWAITFTRACEEVENT']._serialized_end=1173
  _globals['_SCHEDPISETPRIOFTRACEEVENT']._serialized_start=1175
  _globals['_SCHEDPISETPRIOFTRACEEVENT']._serialized_end=1263
  _globals['_SCHEDCPUUTILCFSFTRACEEVENT']._serialized_start=1266
  _globals['_SCHEDCPUUTILCFSFTRACEEVENT']._serialized_end=1594
  _globals['_SCHEDMIGRATETASKFTRACEEVENT']._serialized_start=1597
  _globals['_SCHEDMIGRATETASKFTRACEEVENT']._serialized_end=1734
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/mali.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/mali.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'protos/perfetto/trace/ftrace/mali.proto\x12\x0fperfetto.protos\"Y\n\x1fMaliTracingMarkWriteFtraceEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03pid\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\r\x12\r\n\x05value\x18\x04 \x01(\x05\"u\n\x1dMaliMaliKCPUCQSSETFtraceEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x11\n\tinfo_val1\x18\x02 \x01(\x04\x12\x11\n\tinfo_val2\x18\x03 \x01(\x04\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\x11\n\tkctx_tgid\x18\x05 \x01(\x05\"{\n#MaliMaliKCPUCQSWAITSTARTFtraceEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x11\n\tinfo_val1\x18\x02 \x01(\x04\x12\x11\n\tinfo_val2\x18\x03 \x01(\x04\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\x11\n\tkctx_tgid\x18\x05 \x01(\x05\"y\n!MaliMaliKCPUCQSWAITENDFtraceEvent\x12\n\n\x02id\x18\x01 \x01(\r\x12\x11\n\tinfo_val1\x18\x02 \x01(\x04\x12\x11\n\tinfo_val2\x18\x03 \x01(\x04\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\x11\n\tkctx_tgid\x18\x05 \x01(\x05\"z\n\"MaliMaliKCPUFENCESIGNALFtraceEvent\x12\x11\n\tinfo_val1\x18\x01 \x01(\x04\x12\x11\n\tinfo_val2\x18\x02 \x01(\x04\x12\x11\n\tkctx_tgid\x18\x03 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x01(\r\"}\n%MaliMaliKCPUFENCEWAITSTARTFtraceEvent\x12\x11\n\tinfo_val1\x18\x01 \x01(\x04\x12\x11\n\tinfo_val2\x18\x02 \x01(\x04\x12\x11\n\tkctx_tgid\x18\x03 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x01(\r\"{\n#MaliMaliKCPUFENCEWAITENDFtraceEvent\x12\x11\n\tinfo_val1\x18\x01 \x01(\x04\x12\x11\n\tinfo_val2\x18\x02 \x01(\x04\x12\x11\n\tkctx_tgid\x18\x03 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x04 \x01(\r\x12\n\n\x02id\x18\x05 \x01(\r\"\\\n$MaliMaliCSFINTERRUPTSTARTFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"Z\n\"MaliMaliCSFINTERRUPTENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"l\n4MaliMaliPMMCUHCTLCORESDOWNSCALENOTIFYPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"c\n+MaliMaliPMMCUHCTLCORESNOTIFYPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"d\n,MaliMaliPMMCUHCTLCOREINACTIVEPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"`\n(MaliMaliPMMCUHCTLMCUONRECHECKFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"f\n.MaliMaliPMMCUHCTLSHADERSCOREOFFPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"b\n*MaliMaliPMMCUHCTLSHADERSPENDOFFFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"a\n)MaliMaliPMMCUHCTLSHADERSPENDONFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"c\n+MaliMaliPMMCUHCTLSHADERSREADYOFFFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"W\n\x1fMaliMaliPMMCUINSLEEPFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"S\n\x1bMaliMaliPMMCUOFFFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"R\n\x1aMaliMaliPMMCUONFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"d\n,MaliMaliPMMCUONCOREATTRUPDATEPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"_\n\'MaliMaliPMMCUONGLBREINITPENDFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"V\n\x1eMaliMaliPMMCUONHALTFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"^\n&MaliMaliPMMCUONHWCNTDISABLEFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"]\n%MaliMaliPMMCUONHWCNTENABLEFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"Z\n\"MaliMaliPMMCUONPENDHALTFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"[\n#MaliMaliPMMCUONPENDSLEEPFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"_\n\'MaliMaliPMMCUONSLEEPINITIATEFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"W\n\x1fMaliMaliPMMCUPENDOFFFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"\\\n$MaliMaliPMMCUPENDONRELOADFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"Y\n!MaliMaliPMMCUPOWERDOWNFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04\"Y\n!MaliMaliPMMCURESETWAITFtraceEvent\x12\x11\n\tkctx_tgid\x18\x01 \x01(\x05\x12\x0f\n\x07kctx_id\x18\x02 \x01(\r\x12\x10\n\x08info_val\x18\x03 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.mali_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MALITRACINGMARKWRITEFTRACEEVENT']._serialized_start=60
  _globals['_MALITRACINGMARKWRITEFTRACEEVENT']._serialized_end=149
  _globals['_MALIMALIKCPUCQSSETFTRACEEVENT']._serialized_start=151
  _globals['_MALIMALIKCPUCQSSETFTRACEEVENT']._serialized_end=268
  _globals['_MALIMALIKCPUCQSWAITSTARTFTRACEEVENT']._serialized_start=270
  _globals['_MALIMALIKCPUCQSWAITSTARTFTRACEEVENT']._serialized_end=393
  _globals['_MALIMALIKCPUCQSWAITENDFTRACEEVENT']._serialized_start=395
  _globals['_MALIMALIKCPUCQSWAITENDFTRACEEVENT']._serialized_end=516
  _globals['_MALIMALIKCPUFENCESIGNALFTRACEEVENT']._serialized_start=518
  _globals['_MALIMALIKCPUFENCESIGNALFTRACEEVENT']._serialized_end=640
  _globals['_MALIMALIKCPUFENCEWAITSTARTFTRACEEVENT']._serialized_start=642
  _globals['_MALIMALIKCPUFENCEWAITSTARTFTRACEEVENT']._serialized_end=767
  _globals['_MALIMALIKCPUFENCEWAITENDFTRACEEVENT']._serialized_start=769
  _globals['_MALIMALIKCPUFENCEWAITENDFTRACEEVENT']._serialized_end=892
  _globals['_MALIMALICSFINTERRUPTSTARTFTRACEEVENT']._serialized_start=894
  _globals['_MALIMALICSFINTERRUPTSTARTFTRACEEVENT']._serialized_end=986
  _globals['_MALIMALICSFINTERRUPTENDFTRACEEVENT']._serialized_start=988
  _globals['_MALIMALICSFINTERRUPTENDFTRACEEVENT']._serialized_end=1078
  _globals['_MALIMALIPMMCUHCTLCORESDOWNSCALENOTIFYPENDFTRACEEVENT']._serialized_start=1080
  _globals['_MALIMALIPMMCUHCTLCORESDOWNSCALENOTIFYPENDFTRACEEVENT']._serialized_end=1188
  _globals['_MALIMALIPMMCUHCTLCORESNOTIFYPENDFTRACEEVENT']._serialized_start=1190
  _globals['_MALIMALIPMMCUHCTLCORESNOTIFYPENDFTRACEEVENT']._serialized_end=1289
  _globals['_MALIMALIPMMCUHCTLCOREINACTIVEPENDFTRACEEVENT']._serialized_start=1291
  _globals['_MALIMALIPMMCUHCTLCOREINACTIVEPENDFTRACEEVENT']._serialized_end=1391
  _globals['_MALIMALIPMMCUHCTLMCUONRECHECKFTRACEEVENT']._serialized_start=1393
  _globals['_MALIMALIPMMCUHCTLMCUONRECHECKFTRACEEVENT']._serialized_end=1489
  _globals['_MALIMALIPMMCUHCTLSHADERSCOREOFFPENDFTRACEEVENT']._serialized_start=1491
  _globals['_MALIMALIPMMCUHCTLSHADERSCOREOFFPENDFTRACEEVENT']._serialized_end=1593
  _globals['_MALIMALIPMMCUHCTLSHADERSPENDOFFFTRACEEVENT']._serialized_start=1595
  _globals['_MALIMALIPMMCUHCTLSHADERSPENDOFFFTRACEEVENT']._serialized_end=1693
  _globals['_MALIMALIPMMCUHCTLSHADERSPENDONFTRACEEVENT']._serialized_start=1695
  _globals['_MALIMALIPMMCUHCTLSHADERSPENDONFTRACEEVENT']._serialized_end=1792
  _globals['_MALIMALIPMMCUHCTLSHADERSREADYOFFFTRACEEVENT']._serialized_start=1794
  _globals['_MALIMALIPMMCUHCTLSHADERSREADYOFFFTRACEEVENT']._serialized_end=1893
  _globals['_MALIMALIPMMCUINSLEEPFTRACEEVENT']._serialized_start=1895
  _globals['_MALIMALIPMMCUINSLEEPFTRACEEVENT']._serialized_end=1982
  _globals['_MALIMALIPMMCUOFFFTRACEEVENT']._serialized_start=1984
  _globals['_MALIMALIPMMCUOFFFTRACEEVENT']._serialized_end=2067
  _globals['_MALIMALIPMMCUONFTRACEEVENT']._serialized_start=2069
  _globals['_MALIMALIPMMCUONFTRACEEVENT']._serialized_end=2151
  _globals['_MALIMALIPMMCUONCOREATTRUPDATEPENDFTRACEEVENT']._serialized_start=2153
  _globals['_MALIMALIPMMCUONCOREATTRUPDATEPENDFTRACEEVENT']._serialized_end=2253
  _globals['_MALIMALIPMMCUONGLBREINITPENDFTRACEEVENT']._serialized_start=2255
  _globals['_MALIMALIPMMCUONGLBREINITPENDFTRACEEVENT']._serialized_end=2350
  _globals['_MALIMALIPMMCUONHALTFTRACEEVENT']._serialized_start=2352
  _globals['_MALIMALIPMMCUONHALTFTRACEEVENT']._serialized_end=2438
  _globals['_MALIMALIPMMCUONHWCNTDISABLEFTRACEEVENT']._serialized_start=2440
  _globals['_MALIMALIPMMCUONHWCNTDISABLEFTRACEEVENT']._serialized_end=2534
  _globals['_MALIMALIPMMCUONHWCNTENABLEFTRACEEVENT']._serialized_start=2536
  _globals['_MALIMALIPMMCUONHWCNTENABLEFTRACEEVENT']._serialized_end=2629
  _globals['_MALIMALIPMMCUONPENDHALTFTRACEEVENT']._serialized_start=2631
  _globals['_MALIMALIPMMCUONPENDHALTFTRACEEVENT']._serialized_end=2721
  _globals['_MALIMALIPMMCUONPENDSLEEPFTRACEEVENT']._serialized_start=2723
  _globals['_MALIMALIPMMCUONPENDSLEEPFTRACEEVENT']._serialized_end=2814
  _globals['_MALIMALIPMMCUONSLEEPINITIATEFTRACEEVENT']._serialized_start=2816
  _globals['_MALIMALIPMMCUONSLEEPINITIATEFTRACEEVENT']._serialized_end=2911
  _globals['_MALIMALIPMMCUPENDOFFFTRACEEVENT']._serialized_start=2913
  _globals['_MALIMALIPMMCUPENDOFFFTRACEEVENT']._serialized_end=3000
  _globals['_MALIMALIPMMCUPENDONRELOADFTRACEEVENT']._serialized_start=3002
  _globals['_MALIMALIPMMCUPENDONRELOADFTRACEEVENT']._serialized_end=3094
  _globals['_MALIMALIPMMCUPOWERDOWNFTRACEEVENT']._serialized_start=3096
  _globals['_MALIMALIPMMCUPOWERDOWNFTRACEEVENT']._serialized_end=3185
  _globals['_MALIMALIPMMCURESETWAITFTRACEEVENT']._serialized_start=3187
  _globals['_MALIMALIPMMCURESETWAITFTRACEEVENT']._serialized_end=3276
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/binder.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/binder.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)protos/perfetto/trace/ftrace/binder.proto\x12\x0fperfetto.protos\"\x95\x01\n\x1c\x42inderTransactionFtraceEvent\x12\x10\n\x08\x64\x65\x62ug_id\x18\x01 \x01(\x05\x12\x13\n\x0btarget_node\x18\x02 \x01(\x05\x12\x0f\n\x07to_proc\x18\x03 \x01(\x05\x12\x11\n\tto_thread\x18\x04 \x01(\x05\x12\r\n\x05reply\x18\x05 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x06 \x01(\r\x12\r\n\x05\x66lags\x18\x07 \x01(\r\"8\n$BinderTransactionReceivedFtraceEvent\x12\x10\n\x08\x64\x65\x62ug_id\x18\x01 \x01(\x05\"v\n\x1c\x42inderSetPriorityFtraceEvent\x12\x0c\n\x04proc\x18\x01 \x01(\x05\x12\x0e\n\x06thread\x18\x02 \x01(\x05\x12\x10\n\x08old_prio\x18\x03 \x01(\r\x12\x10\n\x08new_prio\x18\x04 \x01(\r\x12\x14\n\x0c\x64\x65sired_prio\x18\x05 \x01(\r\"$\n\x15\x42inderLockFtraceEvent\x12\x0b\n\x03tag\x18\x01 \x01(\t\"&\n\x17\x42inderLockedFtraceEvent\x12\x0b\n\x03tag\x18\x01 \x01(\t\"&\n\x17\x42inderUnlockFtraceEvent\x12\x0b\n\x03tag\x18\x01 \x01(\t\"}\n$BinderTransactionAllocBufFtraceEvent\x12\x11\n\tdata_size\x18\x01 \x01(\x04\x12\x10\n\x08\x64\x65\x62ug_id\x18\x02 \x01(\x05\x12\x14\n\x0coffsets_size\x18\x03 \x01(\x04\x12\x1a\n\x12\x65xtra_buffers_size\x18\x04 \x01(\x04\"\'\n\x18\x42inderCommandFtraceEvent\x12\x0b\n\x03\x63md\x18\x01 \x01(\r\"&\n\x17\x42inderReturnFtraceEvent\x12\x0b\n\x03\x63md\x18\x01 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.binder_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BINDERTRANSACTIONFTRACEEVENT']._serialized_start=63
  _globals['_BINDERTRANSACTIONFTRACEEVENT']._serialized_end=212
  _globals['_BINDERTRANSACTIONRECEIVEDFTRACEEVENT']._serialized_start=214
  _globals['_BINDERTRANSACTIONRECEIVEDFTRACEEVENT']._serialized_end=270
  _globals['_BINDERSETPRIORITYFTRACEEVENT']._serialized_start=272
  _globals['_BINDERSETPRIORITYFTRACEEVENT']._serialized_end=390
  _globals['_BINDERLOCKFTRACEEVENT']._serialized_start=392
  _globals['_BINDERLOCKFTRACEEVENT']._serialized_end=428
  _globals['_BINDERLOCKEDFTRACEEVENT']._serialized_start=430
  _globals['_BINDERLOCKEDFTRACEEVENT']._serialized_end=468
  _globals['_BINDERUNLOCKFTRACEEVENT']._serialized_start=470
  _globals['_BINDERUNLOCKFTRACEEVENT']._serialized_end=508
  _globals['_BINDERTRANSACTIONALLOCBUFFTRACEEVENT']._serialized_start=510
  _globals['_BINDERTRANSACTIONALLOCBUFFTRACEEVENT']._serialized_end=635
  _globals['_BINDERCOMMANDFTRACEEVENT']._serialized_start=637
  _globals['_BINDERCOMMANDFTRACEEVENT']._serialized_end=676
  _globals['_BINDERRETURNFTRACEEVENT']._serialized_start=678
  _globals['_BINDERRETURNFTRACEEVENT']._serialized_end=716
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/vmscan.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/vmscan.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)protos/perfetto/trace/ftrace/vmscan.proto\x12\x0fperfetto.protos\"`\n%MmVmscanDirectReclaimBeginFtraceEvent\x12\r\n\x05order\x18\x01 \x01(\x05\x12\x15\n\rmay_writepage\x18\x02 \x01(\x05\x12\x11\n\tgfp_flags\x18\x03 \x01(\r\";\n#MmVmscanDirectReclaimEndFtraceEvent\x12\x14\n\x0cnr_reclaimed\x18\x01 \x01(\x04\"H\n\x1dMmVmscanKswapdWakeFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x0b\n\x03zid\x18\x03 \x01(\x05\"-\n\x1eMmVmscanKswapdSleepFtraceEvent\x12\x0b\n\x03nid\x18\x01 \x01(\x05\"\xe9\x01\n\x1cMmShrinkSlabStartFtraceEvent\x12\x13\n\x0b\x63\x61\x63he_items\x18\x01 \x01(\x04\x12\r\n\x05\x64\x65lta\x18\x02 \x01(\x04\x12\x11\n\tgfp_flags\x18\x03 \x01(\r\x12\x0f\n\x07lru_pgs\x18\x04 \x01(\x04\x12\x1c\n\x14nr_objects_to_shrink\x18\x05 \x01(\x03\x12\x13\n\x0bpgs_scanned\x18\x06 \x01(\x04\x12\x0b\n\x03shr\x18\x07 \x01(\x04\x12\x0e\n\x06shrink\x18\x08 \x01(\x04\x12\x12\n\ntotal_scan\x18\t \x01(\x04\x12\x0b\n\x03nid\x18\n \x01(\x05\x12\x10\n\x08priority\x18\x0b \x01(\x05\"\x91\x01\n\x1aMmShrinkSlabEndFtraceEvent\x12\x10\n\x08new_scan\x18\x01 \x01(\x03\x12\x0e\n\x06retval\x18\x02 \x01(\x05\x12\x0b\n\x03shr\x18\x03 \x01(\x04\x12\x0e\n\x06shrink\x18\x04 \x01(\x04\x12\x12\n\ntotal_scan\x18\x05 \x01(\x03\x12\x13\n\x0bunused_scan\x18\x06 \x01(\x03\x12\x0b\n\x03nid\x18\x07 \x01(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.vmscan_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MMVMSCANDIRECTRECLAIMBEGINFTRACEEVENT']._serialized_start=62
  _globals['_MMVMSCANDIRECTRECLAIMBEGINFTRACEEVENT']._serialized_end=158
  _globals['_MMVMSCANDIRECTRECLAIMENDFTRACEEVENT']._serialized_start=160
  _globals['_MMVMSCANDIRECTRECLAIMENDFTRACEEVENT']._serialized_end=219
  _globals['_MMVMSCANKSWAPDWAKEFTRACEEVENT']._serialized_start=221
  _globals['_MMVMSCANKSWAPDWAKEFTRACEEVENT']._serialized_end=293
  _globals['_MMVMSCANKSWAPDSLEEPFTRACEEVENT']._serialized_start=295
  _globals['_MMVMSCANKSWAPDSLEEPFTRACEEVENT']._serialized_end=340
  _globals['_MMSHRINKSLABSTARTFTRACEEVENT']._serialized_start=343
  _globals['_MMSHRINKSLABSTARTFTRACEEVENT']._serialized_end=576
  _globals['_MMSHRINKSLABENDFTRACEEVENT']._serialized_start=579
  _globals['_MMSHRINKSLABENDFTRACEEVENT']._serialized_end=724
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/profiling/heap_graph.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/profiling/heap_graph.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.trace.profiling import deobfuscation_pb2 as protos_dot_perfetto_dot_trace_dot_profiling_dot_deobfuscation__pb2
from protos.perfetto.trace.profiling import profile_common_pb2 as protos_dot_perfetto_dot_trace_dot_profiling_dot_profile__common__pb2

from protos.perfetto.trace.profiling.deobfuscation_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0protos/perfetto/trace/profiling/heap_graph.proto\x12\x0fperfetto.protos\x1a\x33protos/perfetto/trace/profiling/deobfuscation.proto\x1a\x34protos/perfetto/trace/profiling/profile_common.proto\"\xb6\x03\n\rHeapGraphRoot\x12\x16\n\nobject_ids\x18\x01 \x03(\x04\x42\x02\x10\x01\x12\x36\n\troot_type\x18\x02 \x01(\x0e\x32#.perfetto.protos.HeapGraphRoot.Type\"\xd4\x02\n\x04Type\x12\x10\n\x0cROOT_UNKNOWN\x10\x00\x12\x13\n\x0fROOT_JNI_GLOBAL\x10\x01\x12\x12\n\x0eROOT_JNI_LOCAL\x10\x02\x12\x13\n\x0fROOT_JAVA_FRAME\x10\x03\x12\x15\n\x11ROOT_NATIVE_STACK\x10\x04\x12\x15\n\x11ROOT_STICKY_CLASS\x10\x05\x12\x15\n\x11ROOT_THREAD_BLOCK\x10\x06\x12\x15\n\x11ROOT_MONITOR_USED\x10\x07\x12\x16\n\x12ROOT_THREAD_OBJECT\x10\x08\x12\x18\n\x14ROOT_INTERNED_STRING\x10\t\x12\x13\n\x0fROOT_FINALIZING\x10\n\x12\x11\n\rROOT_DEBUGGER\x10\x0b\x12\x1a\n\x16ROOT_REFERENCE_CLEANUP\x10\x0c\x12\x14\n\x10ROOT_VM_INTERNAL\x10\r\x12\x14\n\x10ROOT_JNI_MONITOR\x10\x0e\"\xe4\x03\n\rHeapGraphType\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x13\n\x0blocation_id\x18\x02 \x01(\x04\x12\x12\n\nclass_name\x18\x03 \x01(\t\x12\x13\n\x0bobject_size\x18\x04 \x01(\x04\x12\x15\n\rsuperclass_id\x18\x05 \x01(\x04\x12\x1e\n\x12reference_field_id\x18\x06 \x03(\x04\x42\x02\x10\x01\x12\x31\n\x04kind\x18\x07 \x01(\x0e\x32#.perfetto.protos.HeapGraphType.Kind\x12\x16\n\x0e\x63lassloader_id\x18\x08 \x01(\x04\"\x86\x02\n\x04Kind\x12\x10\n\x0cKIND_UNKNOWN\x10\x00\x12\x0f\n\x0bKIND_NORMAL\x10\x01\x12\x15\n\x11KIND_NOREFERENCES\x10\x02\x12\x0f\n\x0bKIND_STRING\x10\x03\x12\x0e\n\nKIND_ARRAY\x10\x04\x12\x0e\n\nKIND_CLASS\x10\x05\x12\x14\n\x10KIND_CLASSLOADER\x10\x06\x12\x11\n\rKIND_DEXCACHE\x10\x07\x12\x17\n\x13KIND_SOFT_REFERENCE\x10\x08\x12\x17\n\x13KIND_WEAK_REFERENCE\x10\t\x12\x1c\n\x18KIND_FINALIZER_REFERENCE\x10\n\x12\x1a\n\x16KIND_PHANTOM_REFERENCE\x10\x0b\"\xf6\x01\n\x0fHeapGraphObject\x12\x0c\n\x02id\x18\x01 \x01(\x04H\x00\x12\x12\n\x08id_delta\x18\x07 \x01(\x04H\x00\x12\x0f\n\x07type_id\x18\x02 \x01(\x04\x12\x11\n\tself_size\x18\x03 \x01(\x04\x12\x1f\n\x17reference_field_id_base\x18\x06 \x01(\x04\x12\x1e\n\x12reference_field_id\x18\x04 \x03(\x04\x42\x02\x10\x01\x12\x1f\n\x13reference_object_id\x18\x05 \x03(\x04\x42\x02\x10\x01\x12-\n%native_allocation_registry_size_field\x18\x08 \x01(\x03\x42\x0c\n\nidentifier\"\xc0\x02\n\tHeapGraph\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x31\n\x07objects\x18\x02 \x03(\x0b\x32 .perfetto.protos.HeapGraphObject\x12-\n\x05roots\x18\x07 \x03(\x0b\x32\x1e.perfetto.protos.HeapGraphRoot\x12-\n\x05types\x18\t \x03(\x0b\x32\x1e.perfetto.protos.HeapGraphType\x12\x34\n\x0b\x66ield_names\x18\x04 \x03(\x0b\x32\x1f.perfetto.protos.InternedString\x12\x37\n\x0elocation_names\x18\x08 \x03(\x0b\x32\x1f.perfetto.protos.InternedString\x12\x11\n\tcontinued\x18\x05 \x01(\x08\x12\r\n\x05index\x18\x06 \x01(\x04J\x04\x08\x03\x10\x04P\x00')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.profiling.heap_graph_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HEAPGRAPHROOT'].fields_by_name['object_ids']._loaded_options = None
  _globals['_HEAPGRAPHROOT'].fields_by_name['object_ids']._serialized_options = b'\020\001'
  _globals['_HEAPGRAPHTYPE'].fields_by_name['reference_field_id']._loaded_options = None
  _globals['_HEAPGRAPHTYPE'].fields_by_name['reference_field_id']._serialized_options = b'\020\001'
  _globals['_HEAPGRAPHOBJECT'].fields_by_name['reference_field_id']._loaded_options = None
  _globals['_HEAPGRAPHOBJECT'].fields_by_name['reference_field_id']._serialized_options = b'\020\001'
  _globals['_HEAPGRAPHOBJECT'].fields_by_name['reference_object_id']._loaded_options = None
  _globals['_HEAPGRAPHOBJECT'].fields_by_name['reference_object_id']._serialized_options = b'\020\001'
  _globals['_HEAPGRAPHROOT']._serialized_start=177
  _globals['_HEAPGRAPHROOT']._serialized_end=615
  _globals['_HEAPGRAPHROOT_TYPE']._serialized_start=275
  _globals['_HEAPGRAPHROOT_TYPE']._serialized_end=615
  _globals['_HEAPGRAPHTYPE']._serialized_start=618
  _globals['_HEAPGRAPHTYPE']._serialized_end=1102
  _globals['_HEAPGRAPHTYPE_KIND']._serialized_start=840
  _globals['_HEAPGRAPHTYPE_KIND']._serialized_end=1102
  _globals['_HEAPGRAPHOBJECT']._serialized_start=1105
  _globals['_HEAPGRAPHOBJECT']._serialized_end=1351
  _globals['_HEAPGRAPH']._serialized_start=1354
  _globals['_HEAPGRAPH']._serialized_end=1674
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/track_event/chrome_legacy_ipc.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/track_event/chrome_legacy_ipc.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9protos/perfetto/trace/track_event/chrome_legacy_ipc.proto\x12\x0fperfetto.protos\"\xce\x07\n\x0f\x43hromeLegacyIpc\x12\x44\n\rmessage_class\x18\x01 \x01(\x0e\x32-.perfetto.protos.ChromeLegacyIpc.MessageClass\x12\x14\n\x0cmessage_line\x18\x02 \x01(\r\"\xde\x06\n\x0cMessageClass\x12\x15\n\x11\x43LASS_UNSPECIFIED\x10\x00\x12\x14\n\x10\x43LASS_AUTOMATION\x10\x01\x12\x0f\n\x0b\x43LASS_FRAME\x10\x02\x12\x0e\n\nCLASS_PAGE\x10\x03\x12\x0e\n\nCLASS_VIEW\x10\x04\x12\x10\n\x0c\x43LASS_WIDGET\x10\x05\x12\x0f\n\x0b\x43LASS_INPUT\x10\x06\x12\x0e\n\nCLASS_TEST\x10\x07\x12\x10\n\x0c\x43LASS_WORKER\x10\x08\x12\x0e\n\nCLASS_NACL\x10\t\x12\x15\n\x11\x43LASS_GPU_CHANNEL\x10\n\x12\x0f\n\x0b\x43LASS_MEDIA\x10\x0b\x12\x0f\n\x0b\x43LASS_PPAPI\x10\x0c\x12\x10\n\x0c\x43LASS_CHROME\x10\r\x12\x0e\n\nCLASS_DRAG\x10\x0e\x12\x0f\n\x0b\x43LASS_PRINT\x10\x0f\x12\x13\n\x0f\x43LASS_EXTENSION\x10\x10\x12\x1b\n\x17\x43LASS_TEXT_INPUT_CLIENT\x10\x11\x12\x14\n\x10\x43LASS_BLINK_TEST\x10\x12\x12\x17\n\x13\x43LASS_ACCESSIBILITY\x10\x13\x12\x13\n\x0f\x43LASS_PRERENDER\x10\x14\x12\x14\n\x10\x43LASS_CHROMOTING\x10\x15\x12\x18\n\x14\x43LASS_BROWSER_PLUGIN\x10\x16\x12\x1a\n\x16\x43LASS_ANDROID_WEB_VIEW\x10\x17\x12\x13\n\x0f\x43LASS_NACL_HOST\x10\x18\x12\x19\n\x15\x43LASS_ENCRYPTED_MEDIA\x10\x19\x12\x0e\n\nCLASS_CAST\x10\x1a\x12\x19\n\x15\x43LASS_GIN_JAVA_BRIDGE\x10\x1b\x12!\n\x1d\x43LASS_CHROME_UTILITY_PRINTING\x10\x1c\x12\x13\n\x0f\x43LASS_OZONE_GPU\x10\x1d\x12\x12\n\x0e\x43LASS_WEB_TEST\x10\x1e\x12\x17\n\x13\x43LASS_NETWORK_HINTS\x10\x1f\x12\x1f\n\x1b\x43LASS_EXTENSIONS_GUEST_VIEW\x10 \x12\x14\n\x10\x43LASS_GUEST_VIEW\x10!\x12\x1f\n\x1b\x43LASS_MEDIA_PLAYER_DELEGATE\x10\"\x12\x1a\n\x16\x43LASS_EXTENSION_WORKER\x10#\x12\x1c\n\x18\x43LASS_SUBRESOURCE_FILTER\x10$\x12\x1b\n\x17\x43LASS_UNFREEZABLE_FRAME\x10%')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.track_event.chrome_legacy_ipc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CHROMELEGACYIPC']._serialized_start=79
  _globals['_CHROMELEGACYIPC']._serialized_end=1053
  _globals['_CHROMELEGACYIPC_MESSAGECLASS']._serialized_start=191
  _globals['_CHROMELEGACYIPC_MESSAGECLASS']._serialized_end=1053
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/config/android/android_log_config.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/config/android/android_log_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protos.perfetto.common import android_log_constants_pb2 as protos_dot_perfetto_dot_common_dot_android__log__constants__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7protos/perfetto/config/android/android_log_config.proto\x12\x0fperfetto.protos\x1a\x32protos/perfetto/common/android_log_constants.proto\"\x94\x01\n\x10\x41ndroidLogConfig\x12.\n\x07log_ids\x18\x01 \x03(\x0e\x32\x1d.perfetto.protos.AndroidLogId\x12\x35\n\x08min_prio\x18\x03 \x01(\x0e\x32#.perfetto.protos.AndroidLogPriority\x12\x13\n\x0b\x66ilter_tags\x18\x04 \x03(\tJ\x04\x08\x02\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.config.android.android_log_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANDROIDLOGCONFIG']._serialized_start=129
  _globals['_ANDROIDLOGCONFIG']._serialized_end=277
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: protos/perfetto/trace/ftrace/mdss.proto
# Protobuf Python Version: 5.27.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    1,
    '',
    'protos/perfetto/trace/ftrace/mdss.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'protos/perfetto/trace/ftrace/mdss.proto\x12\x0fperfetto.protos\"@\n\x18MdpCmdKickoffFtraceEvent\x12\x0f\n\x07\x63tl_num\x18\x01 \x01(\r\x12\x13\n\x0bkickoff_cnt\x18\x02 \x01(\x05\"Z\n\x14MdpCommitFtraceEvent\x12\x0b\n\x03num\x18\x01 \x01(\r\x12\x10\n\x08play_cnt\x18\x02 \x01(\r\x12\x10\n\x08\x63lk_rate\x18\x03 \x01(\r\x12\x11\n\tbandwidth\x18\x04 \x01(\x04\"[\n\x17MdpPerfSetOtFtraceEvent\x12\x0c\n\x04pnum\x18\x01 \x01(\r\x12\x0e\n\x06xin_id\x18\x02 \x01(\r\x12\x0e\n\x06rd_lim\x18\x03 \x01(\r\x12\x12\n\nis_vbif_rt\x18\x04 \x01(\r\"\x8c\x02\n\x18MdpSsppChangeFtraceEvent\x12\x0b\n\x03num\x18\x01 \x01(\r\x12\x10\n\x08play_cnt\x18\x02 \x01(\r\x12\r\n\x05mixer\x18\x03 \x01(\r\x12\r\n\x05stage\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\r\x12\r\n\x05img_w\x18\x07 \x01(\r\x12\r\n\x05img_h\x18\x08 \x01(\r\x12\r\n\x05src_x\x18\t \x01(\r\x12\r\n\x05src_y\x18\n \x01(\r\x12\r\n\x05src_w\x18\x0b \x01(\r\x12\r\n\x05src_h\x18\x0c \x01(\r\x12\r\n\x05\x64st_x\x18\r \x01(\r\x12\r\n\x05\x64st_y\x18\x0e \x01(\r\x12\r\n\x05\x64st_w\x18\x0f \x01(\r\x12\r\n\x05\x64st_h\x18\x10 \x01(\r\"S\n\x1bTracingMarkWriteFtraceEvent\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x12\n\ntrace_name\x18\x02 \x01(\t\x12\x13\n\x0btrace_begin\x18\x03 \x01(\r\"d\n\x1dMdpCmdPingpongDoneFtraceEvent\x12\x0f\n\x07\x63tl_num\x18\x01 \x01(\r\x12\x10\n\x08intf_num\x18\x02 \x01(\r\x12\x0e\n\x06pp_num\x18\x03 \x01(\r\x12\x10\n\x08koff_cnt\x18\x04 \x01(\x05\"\xa4\x01\n\x17MdpCompareBwFtraceEvent\x12\x0e\n\x06new_ab\x18\x01 \x01(\x04\x12\x0e\n\x06new_ib\x18\x02 \x01(\x04\x12\x0e\n\x06new_wb\x18\x03 \x01(\x04\x12\x0e\n\x06old_ab\x18\x04 \x01(\x04\x12\x0e\n\x06old_ib\x18\x05 \x01(\x04\x12\x0e\n\x06old_wb\x18\x06 \x01(\x04\x12\x16\n\x0eparams_changed\x18\x07 \x01(\r\x12\x11\n\tupdate_bw\x18\x08 \x01(\r\"p\n\x1eMdpPerfSetPanicLutsFtraceEvent\x12\x0c\n\x04pnum\x18\x01 \x01(\r\x12\x0b\n\x03\x66mt\x18\x02 \x01(\r\x12\x0c\n\x04mode\x18\x03 \x01(\r\x12\x11\n\tpanic_lut\x18\x04 \x01(\r\x12\x12\n\nrobust_lut\x18\x05 \x01(\r\"\x89\x02\n\x15MdpSsppSetFtraceEvent\x12\x0b\n\x03num\x18\x01 \x01(\r\x12\x10\n\x08play_cnt\x18\x02 \x01(\r\x12\r\n\x05mixer\x18\x03 \x01(\r\x12\r\n\x05stage\x18\x04 \x01(\r\x12\r\n\x05\x66lags\x18\x05 \x01(\r\x12\x0e\n\x06\x66ormat\x18\x06 \x01(\r\x12\r\n\x05img_w\x18\x07 \x01(\r\x12\r\n\x05img_h\x18\x08 \x01(\r\x12\r\n\x05src_x\x18\t \x01(\r\x12\r\n\x05src_y\x18\n \x01(\r\x12\r\n\x05src_w\x18\x0b \x01(\r\x12\r\n\x05src_h\x18\x0c \x01(\r\x12\r\n\x05\x64st_x\x18\r \x01(\r\x12\r\n\x05\x64st_y\x18\x0e \x01(\r\x12\r\n\x05\x64st_w\x18\x0f \x01(\r\x12\r\n\x05\x64st_h\x18\x10 \x01(\r\"A\n\x1cMdpCmdReadptrDoneFtraceEvent\x12\x0f\n\x07\x63tl_num\x18\x01 \x01(\r\x12\x10\n\x08koff_cnt\x18\x02 \x01(\x05\"I\n\x15MdpMisrCrcFtraceEvent\x12\x10\n\x08\x62lock_id\x18\x01 \x01(\r\x12\x11\n\tvsync_cnt\x18\x02 \x01(\r\x12\x0b\n\x03\x63rc\x18\x03 \x01(\r\"}\n\x1cMdpPerfSetQosLutsFtraceEvent\x12\x0c\n\x04pnum\x18\x01 \x01(\r\x12\x0b\n\x03\x66mt\x18\x02 \x01(\r\x12\x0c\n\x04intf\x18\x03 \x01(\r\x12\x0b\n\x03rot\x18\x04 \x01(\r\x12\n\n\x02\x66l\x18\x05 \x01(\r\x12\x0b\n\x03lut\x18\x06 \x01(\r\x12\x0e\n\x06linear\x18\x07 \x01(\r\"N\n\x1aMdpTraceCounterFtraceEvent\x12\x0b\n\x03pid\x18\x01 \x01(\x05\x12\x14\n\x0c\x63ounter_name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x05\"-\n\x1aMdpCmdReleaseBwFtraceEvent\x12\x0f\n\x07\x63tl_num\x18\x01 \x01(\r\".\n\x19MdpMixerUpdateFtraceEvent\x12\x11\n\tmixer_num\x18\x01 \x01(\r\"\xa0\x01\n\x1dMdpPerfSetWmLevelsFtraceEvent\x12\x0c\n\x04pnum\x18\x01 \x01(\r\x12\x11\n\tuse_space\x18\x02 \x01(\r\x12\x16\n\x0epriority_bytes\x18\x03 \x01(\r\x12\x0b\n\x03wm0\x18\x04 \x01(\r\x12\x0b\n\x03wm1\x18\x05 \x01(\r\x12\x0b\n\x03wm2\x18\x06 \x01(\r\x12\x0e\n\x06mb_cnt\x18\x07 \x01(\r\x12\x0f\n\x07mb_size\x18\x08 \x01(\r\"H\n\x1fMdpVideoUnderrunDoneFtraceEvent\x12\x0f\n\x07\x63tl_num\x18\x01 \x01(\r\x12\x14\n\x0cunderrun_cnt\x18\x02 \x01(\r\"E\n\x1dMdpCmdWaitPingpongFtraceEvent\x12\x0f\n\x07\x63tl_num\x18\x01 \x01(\r\x12\x13\n\x0bkickoff_cnt\x18\x02 \x01(\x05\"\xce\x01\n\x1dMdpPerfPrefillCalcFtraceEvent\x12\x0c\n\x04pnum\x18\x01 \x01(\r\x12\x13\n\x0blatency_buf\x18\x02 \x01(\r\x12\n\n\x02ot\x18\x03 \x01(\r\x12\r\n\x05y_buf\x18\x04 \x01(\r\x12\x10\n\x08y_scaler\x18\x05 \x01(\r\x12\x10\n\x08pp_lines\x18\x06 \x01(\r\x12\x10\n\x08pp_bytes\x18\x07 \x01(\r\x12\x0f\n\x07post_sc\x18\x08 \x01(\r\x12\x11\n\tfbc_bytes\x18\t \x01(\r\x12\x15\n\rprefill_bytes\x18\n \x01(\r\"Q\n\x1bMdpPerfUpdateBusFtraceEvent\x12\x0e\n\x06\x63lient\x18\x01 \x01(\x05\x12\x10\n\x08\x61\x62_quota\x18\x02 \x01(\x04\x12\x10\n\x08ib_quota\x18\x03 \x01(\x04\"0\n\x1fRotatorBwAoAsContextFtraceEvent\x12\r\n\x05state\x18\x01 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.perfetto.trace.ftrace.mdss_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MDPCMDKICKOFFFTRACEEVENT']._serialized_start=60
  _globals['_MDPCMDKICKOFFFTRACEEVENT']._serialized_end=124
  _globals['_MDPCOMMITFTRACEEVENT']._serialized_start=126
  _globals['_MDPCOMMITFTRACEEVENT']._serialized_end=216
  _globals['_MDPPERFSETOTFTRACEEVENT']._serialized_start=218
  _globals['_MDPPERFSETOTFTRACEEVENT']._serialized_end=309
  _globals['_MDPSSPPCHANGEFTRACEEVENT']._serialized_start=312
  _globals['_MDPSSPPCHANGEFTRACEEVENT']._serialized_end=580
  _globals['_TRACINGMARKWRITEFTRACEEVENT']._serialized_start=582
  _globals['_TRACINGMARKWRITEFTRACEEVENT']._serialized_end=665
  _globals['_MDPCMDPINGPONGDONEFTRACEEVENT']._serialized_start=667
  _globals['_MDPCMDPINGPONGDONEFTRACEEVENT']._serialized_end=767
  _globals['_MDPCOMPAREBWFTRACEEVENT']._serialized_start=770
  _globals['_MDPCOMPAREBWFTRACEEVENT']._serialized_end=934
  _globals['_MDPPERFSETPANICLUTSFTRACEEVENT']._serialized_start=936
  _globals['_MDPPERFSETPANICLUTSFTRACEEVENT']._serialized_end=1048
  _globals['_MDPSSPPSETFTRACEEVENT']._serialized_start=1051
  _globals['_MDPSSPPSETFTRACEEVENT']._serialized_end=1316
  _globals['_MDPCMDREADPTRDONEFTRACEEVENT']._serialized_start=1318
  _globals['_MDPCMDREADPTRDONEFTRACEEVENT']._serialized_end=1383
  _globals['_MDPMISRCRCFTRACEEVENT']._serialized_start=1385
  _globals['_MDPMISRCRCFTRACEEVENT']._serialized_end=1458
  _globals['_MDPPERFSETQOSLUTSFTRACEEVENT']._serialized_start=1460
  _globals['_MDPPERFSETQOSLUTSFTRACEEVENT']._serialized_end=1585
  _globals['_MDPTRACECOUNTERFTRACEEVENT']._serialized_start=1587
  _globals['_MDPTRACECOUNTERFTRACEEVENT']._serialized_end=1665
  _globals['_MDPCMDRELEASEBWFTRACEEVENT']._serialized_start=1667
  _globals['_MDPCMDRELEASEBWFTRACEEVENT']._serialized_end=1712
  _globals['_MDPMIXERUPDATEFTRACEEVENT']._serialized_start=1714
  _globals['_MDPMIXERUPDATEFTRACEEVENT']._serialized_end=1760
  _globals['_MDPPERFSETWMLEVELSFTRACEEVENT']._serialized_start=1763
  _globals['_MDPPERFSETWMLEVELSFTRACEEVENT']._serialized_end=1923
  _globals['_MDPVIDEOUNDERRUNDONEFTRACEEVENT']._serialized_start=1925
  _globals['_MDPVIDEOUNDERRUNDONEFTRACEEVENT']._serialized_end=1997
  _globals['_MDPCMDWAITPINGPONGFTRACEEVENT']._serialized_start=1999
  _globals['_MDPCMDWAITPINGPONGFTRACEEVENT']._serialized_end=2068
  _globals['_MDPPERFPREFILLCALCFTRACEEVENT']._serialized_start=2071
  _globals['_MDPPERFPREFILLCALCFTRACEEVENT']._serialized_end=2277
  _globals['_MDPPERFUPDATEBUSFTRACEEVENT']._serialized_start=2279
  _globals['_MDPPERFUPDATEBUSFTRACEEVENT']._serialized_end=2360
  _globals['_ROTATORBWAOASCONTEXTFTRACEEVENT']._serialized_start=2362
  _globals['_ROTATORBWAOASCONTEXTFTRACEEVENT']._serialized_end=2410
# @@protoc_insertion_point(module_scope)
